@@ -3,19 +3,19 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from openbb_terminal.alternative.hackernews_model import get_stories
 from openbb_terminal.decorators import log_start_end
-from openbb_terminal.helper_funcs import (
-    export_data,
-    print_rich_table,
-)
+from openbb_terminal.helper_funcs import export_data, print_rich_table
 
 logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
-def display_stories(limit: int = 10, export: str = "", sheet_name: str = None) -> None:
+def display_stories(
+    limit: int = 10, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """View top stories from HackerNews.
     Parameters
     ----------
