@@ -3,11 +3,12 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
+from openbb_terminal.common import feedparser_model
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import export_data
 from openbb_terminal.rich_config import console
-from openbb_terminal.common import feedparser_model
 
 logger = logging.getLogger(__name__)
 
@@ -18,7 +19,7 @@ def display_news(
     sources: str = "",
     limit: int = 5,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     sort: str = "published",
 ):
     """Plots news for a given term and source. [Source: Feedparser]
