@@ -3,27 +3,26 @@ __docformat__ = "numpy"
 
 import logging
 import os
-from typing import Optional, List
+from typing import List, Optional
 
 import matplotlib.pyplot as plt
+import mplfinance as mpf
 import numpy as np
 import pandas as pd
 from pandas.plotting import register_matplotlib_converters
-import mplfinance as mpf
 
-from openbb_terminal.config_terminal import theme
-from openbb_terminal.common.technical_analysis import momentum_model
+from openbb_terminal.common.technical_analysis import momentum_model, ta_helpers
 from openbb_terminal.config_plot import PLOT_DPI
+from openbb_terminal.config_terminal import theme
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
-    plot_autoscale,
-    reindex_dates,
     is_valid_axes_count,
+    plot_autoscale,
     print_rich_table,
+    reindex_dates,
 )
 from openbb_terminal.rich_config import console
-from openbb_terminal.common.technical_analysis import ta_helpers
 
 logger = logging.getLogger(__name__)
 
@@ -37,7 +36,7 @@ def display_cci(
     scalar: float = 0.0015,
     symbol: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Plots CCI Indicator
@@ -132,7 +131,7 @@ def display_macd(
     n_signal: int = 9,
     symbol: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Plots MACD signal
@@ -227,7 +226,7 @@ def display_rsi(
     drift: int = 1,
     symbol: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Plots RSI Indicator
@@ -317,7 +316,7 @@ def display_stoch(
     slowkperiod: int = 3,
     symbol: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Plots stochastic oscillator signal
@@ -416,7 +415,7 @@ def display_fisher(
     window: int = 14,
     symbol: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Plots Fisher Indicator
@@ -511,7 +510,7 @@ def display_cg(
     window: int = 14,
     symbol: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Plots center of gravity Indicator
@@ -584,7 +583,7 @@ def display_clenow_momentum(
     symbol: str = "",
     window: int = 90,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Prints table and plots clenow momentum
