@@ -1,13 +1,6 @@
 import os
-
-import dotenv
-
-from openbb_terminal.core.config.paths import USER_ENV_FILE, REPOSITORY_ENV_FILE
 from openbb_terminal.base_helpers import load_env_vars
 
-dotenv.load_dotenv(USER_ENV_FILE)
-dotenv.load_dotenv(REPOSITORY_ENV_FILE, override=True)
-
 PLOT_DPI = load_env_vars("OPENBB_PLOT_DPI", int, 100, "settings")
 
 # Backend to use for plotting
