@@ -5,6 +5,7 @@ from os import environ
 from types import MethodType
 from typing import Callable, List
 from unittest.mock import patch
+
 from openbb_terminal.helper_funcs import check_file_type_saved, check_positive
 from openbb_terminal.rich_config import get_ordered_list_sources
 
@@ -213,7 +214,7 @@ def __patch_controller_functions(controller):
         ),
     ]
 
-    if environ.get("DEBUG_MODE", "false") != "true":
+    if str(environ.get("DEBUG_MODE", "false")).lower() != "true":
         rich.start()
     patched_function_list = []
     for patcher in patcher_list:
@@ -221,7 +222,7 @@ def __patch_controller_functions(controller):
 
     yield patched_function_list
 
-    if environ.get("DEBUG_MODE", "false") != "true":
+    if str(environ.get("DEBUG_MODE", "false")).lower() != "true":
         rich.stop()
     for patcher in patcher_list:
         patcher.stop()
@@ -318,7 +319,7 @@ def build_controller_choice_map(controller) -> dict:
                 argument_parser=argument_parser
             )
         except Exception as exception:
-            if environ.get("DEBUG_MODE", "false") == "true":
+            if str(environ.get("DEBUG_MODE", "false")).lower() == "true":
                 raise Exception(
                     f"On command : `{command}`.\n{str(exception)}"
                 ) from exception
