@@ -1,26 +1,10 @@
 # IMPORTATION STANDARD
-from pathlib import Path
 import os
-from dotenv import load_dotenv
-
-
-def load_dotenv_with_priority():
-    """Loads the dotenv files in the following order:
-    1. Repository .env file
-    2. Package .env file
-    3. User .env file
-
-    This allows the user to override the package settings with their own
-    settings, and the package to override the repository settings.
-    """
-    load_dotenv(REPOSITORY_ENV_FILE, override=True)
-    load_dotenv(PACKAGE_ENV_FILE, override=True)
-    load_dotenv(USER_ENV_FILE, override=True)
+from pathlib import Path
 
 
 def get_user_data_directory():
     """Gets user data path from .env file or returns default path"""
-    load_dotenv_with_priority()
     if os.getenv("OPENBB_USER_DATA_DIRECTORY"):
         user_data_directory = Path(os.getenv("OPENBB_USER_DATA_DIRECTORY"))
     else:
@@ -36,6 +20,7 @@ REPOSITORY_ENV_FILE = REPOSITORY_DIRECTORY / ".env"
 PACKAGE_ENV_FILE = PACKAGE_DIRECTORY / ".env"
 
 SETTINGS_DIRECTORY = HOME_DIRECTORY / ".openbb_terminal"
+HIST_FILE_PATH = SETTINGS_DIRECTORY / ".openbb_terminal.his"
 USER_ENV_FILE = SETTINGS_DIRECTORY / ".env"
 USER_DATA_DIRECTORY = get_user_data_directory()
 USER_EXPORTS_DIRECTORY = USER_DATA_DIRECTORY / "exports"
