@@ -1,20 +1,15 @@
 # IMPORTATION STANDARD
-import platform
 import json
 import logging
+import platform
 from types import FunctionType, ModuleType
 
 # IMPORTATION THIRDPARTY
-
-
 # IMPORTATION INTERNAL
 import openbb_terminal.feature_flags as obbff
 from openbb_terminal import config_terminal as cfg
-from openbb_terminal.terminal_helper import is_packaged_application
-from openbb_terminal.core.log.generation.path_tracking_file_handler import (
-    PathTrackingFileHandler,
-)
-
+from openbb_terminal.core.log.generation.common import do_rollover
+from openbb_terminal.terminal_helper import is_installer
 
 SENSITIVE_WORDS = [
     "API",
@@ -31,14 +26,15 @@ SENSITIVE_WORDS = [
 logger = logging.getLogger(__name__)
 
 
-def log_all_settings() -> None:
+def log_all_settings(with_rollover: bool = True) -> None:
     """Log all settings"""
     log_settings()
     log_config_terminal()
     log_feature_flags()
     log_keys()
 
-    do_rollover()
+    if with_rollover:
+        do_rollover()
 
 
 def log_settings() -> None:
@@ -58,7 +54,7 @@ def log_settings() -> None:
     settings_dict["watermark"] = "True" if obbff.USE_WATERMARK else "False"
     settings_dict["autoscaling"] = "True" if obbff.USE_PLOT_AUTOSCALING else "False"
     settings_dict["dt"] = "True" if obbff.USE_DATETIME else "False"
-    settings_dict["packaged"] = "True" if is_packaged_application() else "False"
+    settings_dict["packaged"] = "True" if is_installer() else "False"
     settings_dict["python"] = str(platform.python_version())
     settings_dict["os"] = str(platform.system())
 
@@ -116,11 +112,3 @@ def log_keys() -> None:
             current_keys[cfg_var_name] = "not_defined"
 
     logger.info("KEYS: %s ", json.dumps(current_keys))
-
-
-def do_rollover():
-    """RollOver the log file."""
-
-    for handler in logging.getLogger().handlers:
-        if isinstance(handler, PathTrackingFileHandler):
-            handler.doRollover()
