@@ -4,20 +4,21 @@ __docformat__ = "numpy"
 import logging
 import os
 from typing import List, Optional
+
 import matplotlib.pyplot as plt
+
 from openbb_terminal import config_terminal as cfg
 from openbb_terminal.config_plot import PLOT_DPI
 from openbb_terminal.cryptocurrency.defi import cryptosaurio_model
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
+    is_valid_axes_count,
     plot_autoscale,
     print_rich_table,
-    is_valid_axes_count,
 )
 from openbb_terminal.rich_config import console
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -25,7 +26,7 @@ logger = logging.getLogger(__name__)
 def display_anchor_data(
     address: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     show_transactions: bool = False,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
