@@ -4,6 +4,7 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from openbb_terminal.cryptocurrency.defi import substack_model
 from openbb_terminal.decorators import log_start_end
@@ -14,7 +15,7 @@ logger = logging.getLogger(__name__)
 
 @log_start_end(log=logger)
 def display_newsletters(
-    limit: int = 10, export: str = "", sheet_name: str = None
+    limit: int = 10, export: str = "", sheet_name: Optional[str] = None
 ) -> None:
     """Prints table showing DeFi related substack newsletters.
     [Source: substack.com]
