@@ -3,10 +3,10 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
-from openbb_terminal.decorators import check_api_key
 from openbb_terminal.cryptocurrency.discovery import coinmarketcap_model
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
 from openbb_terminal.rich_config import console
 
@@ -20,7 +20,7 @@ def display_cmc_top_coins(
     sortby: str = "CMC_Rank",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing top n coins. [Source: CoinMarketCap]
 
