@@ -3,6 +3,7 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 import openbb_terminal.cryptocurrency.discovery.coinpaprika_model as paprika
 from openbb_terminal.decorators import log_start_end
@@ -20,7 +21,7 @@ def display_search_results(
     sortby: str = "id",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing Search over CoinPaprika. [Source: CoinPaprika]
 
