@@ -4,10 +4,7 @@ __docformat__ = "numpy"
 # pylint: disable=R0904, C0302, W0622, C0201
 import argparse
 import logging
-from typing import List
-
-from openbb_terminal.custom_prompt_toolkit import NestedCompleter
-
+from typing import List, Optional
 
 from openbb_terminal import feature_flags as obbff
 from openbb_terminal.cryptocurrency.discovery import (
@@ -20,6 +17,7 @@ from openbb_terminal.cryptocurrency.discovery import (
     pycoingecko_model,
     pycoingecko_view,
 )
+from openbb_terminal.custom_prompt_toolkit import NestedCompleter
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     EXPORT_ONLY_RAW_DATA_ALLOWED,
@@ -27,7 +25,7 @@ from openbb_terminal.helper_funcs import (
 )
 from openbb_terminal.menu import session
 from openbb_terminal.parent_classes import BaseController
-from openbb_terminal.rich_config import console, MenuText, get_ordered_list_sources
+from openbb_terminal.rich_config import MenuText, console, get_ordered_list_sources
 
 logger = logging.getLogger(__name__)
 
@@ -50,13 +48,23 @@ class DiscoveryController(BaseController):
     PATH = "/crypto/disc/"
     CHOICES_GENERATION = True
 
-    def __init__(self, queue: List[str] = None):
+    def __init__(self, queue: Optional[List[str]] = None):
         """Constructor"""
         super().__init__(queue)
 
         if session and obbff.USE_PROMPT_TOOLKIT:
             choices: dict = self.choices_default
 
+            ordered_list_sources_top = get_ordered_list_sources(f"{self.PATH}top")
+            if ordered_list_sources_top and ordered_list_sources_top[0] == "CoinGecko":
+                choices["top"]["--sort"] = {
+                    c: {} for c in pycoingecko_view.COINS_COLUMNS
+                }
+            else:
+                choices["top"]["--sort"] = {c: {} for c in coinmarketcap_model.FILTERS}
+
+            choices["top"]["-s"] = choices["top"]["--sort"]
+
             self.completer = NestedCompleter.from_nested_dict(choices)
 
     def print_help(self):
@@ -83,11 +91,6 @@ class DiscoveryController(BaseController):
         else:
             argument_sort_default = "CMC_Rank"
 
-        if ordered_list_sources_top and ordered_list_sources_top[0] == "CoinGecko":
-            argument_sort_choices = pycoingecko_view.COINS_COLUMNS
-        else:
-            argument_sort_choices = coinmarketcap_model.FILTERS
-
         parser = argparse.ArgumentParser(
             prog="top",
             add_help=False,
@@ -126,7 +129,6 @@ class DiscoveryController(BaseController):
             nargs="+",
             help="Sort by given column. Default: Market Cap Rank",
             default=argument_sort_default,
-            choices=argument_sort_choices,
             metavar="SORTBY",
         )
         parser.add_argument(
