@@ -3,6 +3,7 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from pandas.plotting import register_matplotlib_converters
 
@@ -37,7 +38,7 @@ def display_coins(
     limit: int = 250,
     sortby: str = "Symbol",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     ascend: bool = False,
 ) -> None:
     """Prints table showing top coins [Source: CoinGecko]
@@ -104,7 +105,7 @@ def display_gainers(
     limit: int = 20,
     sortby: str = "market_cap_rank",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing Largest Gainers - coins which gain the most in given period. [Source: CoinGecko]
 
@@ -150,7 +151,7 @@ def display_losers(
     interval: str = "1h",
     limit: int = 20,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     sortby: str = "Market Cap Rank",
 ) -> None:
     """Prints table showing Largest Losers - coins which lost the most in given period of time. [Source: CoinGecko]
@@ -193,7 +194,7 @@ def display_losers(
 
 
 @log_start_end(log=logger)
-def display_trending(export: str = "", sheet_name: str = None) -> None:
+def display_trending(export: str = "", sheet_name: Optional[str] = None) -> None:
     """Prints table showing trending coins [Source: CoinGecko]
 
     Parameters
