@@ -5,11 +5,10 @@ import logging
 import os
 from typing import Optional
 
-from openbb_terminal.cryptocurrency.overview import cryptopanic_model
-from openbb_terminal.decorators import log_start_end
-from openbb_terminal.helper_funcs import export_data, print_rich_table
-from openbb_terminal.decorators import check_api_key
 from openbb_terminal.cryptocurrency.dataframe_helpers import prettify_column_names
+from openbb_terminal.cryptocurrency.overview import cryptopanic_model
+from openbb_terminal.decorators import check_api_key, log_start_end
+from openbb_terminal.helper_funcs import export_data, print_rich_table
 
 logger = logging.getLogger(__name__)
 
@@ -27,7 +26,7 @@ def display_news(
     limit: int = 25,
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing recent posts from CryptoPanic news aggregator platform.
     [Source: https://cryptopanic.com/]
