@@ -7,17 +7,22 @@ import logging
 import os
 from datetime import datetime, timedelta
 from typing import List, Optional
-import pandas as pd
-import numpy as np
-from matplotlib import pyplot as plt
-from matplotlib import ticker
-from matplotlib import dates as mdates
 
+import numpy as np
+import pandas as pd
+from matplotlib import (
+    dates as mdates,
+    pyplot as plt,
+    ticker,
+)
+
+from openbb_terminal import (
+    config_plot as cfgPlot,
+    feature_flags as obbff,
+)
 from openbb_terminal.config_terminal import theme
-from openbb_terminal import feature_flags as obbff
 from openbb_terminal.cryptocurrency import cryptocurrency_helpers
-from openbb_terminal.decorators import check_api_key
-from openbb_terminal import config_plot as cfgPlot
+from openbb_terminal.cryptocurrency.dataframe_helpers import prettify_paragraph
 from openbb_terminal.cryptocurrency.due_diligence.messari_model import (
     get_available_timeseries,
     get_fundraising,
@@ -31,16 +36,15 @@ from openbb_terminal.cryptocurrency.due_diligence.messari_model import (
     get_team,
     get_tokenomics,
 )
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
+    is_valid_axes_count,
     lambda_long_number_format,
     plot_autoscale,
     print_rich_table,
-    is_valid_axes_count,
 )
 from openbb_terminal.rich_config import console
-from openbb_terminal.cryptocurrency.dataframe_helpers import prettify_paragraph
 
 logger = logging.getLogger(__name__)
 
@@ -52,7 +56,7 @@ def display_messari_timeseries_list(
     query: str = "",
     only_free: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing messari timeseries list
     [Source: https://messari.io/]
@@ -110,7 +114,7 @@ def display_messari_timeseries(
     end_date: Optional[str] = None,
     interval: str = "1d",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Plots messari timeseries
@@ -189,7 +193,7 @@ def display_marketcap_dominance(
     end_date: Optional[str] = None,
     interval: str = "1d",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Plots market dominance of a coin over time
@@ -252,7 +256,9 @@ def display_marketcap_dominance(
 
 @log_start_end(log=logger)
 @check_api_key(["API_MESSARI_KEY"])
-def display_links(symbol: str, export: str = "", sheet_name: str = None) -> None:
+def display_links(
+    symbol: str, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Prints table showing coin links
     [Source: https://messari.io/]
 
@@ -293,7 +299,7 @@ def display_roadmap(
     ascend: bool = True,
     limit: int = 5,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Plots coin roadmap
@@ -395,7 +401,7 @@ def display_roadmap(
 def display_tokenomics(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Plots coin tokenomics
@@ -481,7 +487,7 @@ def display_tokenomics(
 def display_project_info(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing project info
     [Source: https://messari.io/]
@@ -523,7 +529,7 @@ def display_project_info(
 def display_investors(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing coin investors
     [Source: https://messari.io/]
@@ -571,7 +577,7 @@ def display_investors(
 def display_team(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing coin team
     [Source: https://messari.io/]
@@ -619,7 +625,7 @@ def display_team(
 def display_governance(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing coin governance
     [Source: https://messari.io/]
@@ -658,7 +664,7 @@ def display_governance(
 def display_fundraising(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Display coin fundraising
