@@ -4,20 +4,18 @@ from typing import List, Optional
 
 from matplotlib import pyplot as plt
 
-from openbb_terminal.config_terminal import theme
-from openbb_terminal.decorators import check_api_key
 from openbb_terminal import config_plot as cfgPlot
+from openbb_terminal.config_terminal import theme
 from openbb_terminal.cryptocurrency.due_diligence.santiment_model import (
     get_github_activity,
 )
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
-    plot_autoscale,
     is_valid_axes_count,
+    plot_autoscale,
 )
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -30,7 +28,7 @@ def display_github_activity(
     end_date: Optional[str] = None,
     interval: str = "1d",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Returns a list of github activity for a given coin and time interval.
