@@ -3,23 +3,22 @@ import logging
 import os
 from typing import List, Optional
 
+import pandas as pd
 from matplotlib import pyplot as plt
 
-import pandas as pd
-from openbb_terminal.config_terminal import theme
 from openbb_terminal.config_plot import PLOT_DPI
+from openbb_terminal.config_terminal import theme
 from openbb_terminal.cryptocurrency.due_diligence.tokenterminal_model import (
+    METRICS,
+    get_description,
     get_fundamental_metric_from_project,
     get_project_ids,
-    get_description,
-    METRICS,
 )
-from openbb_terminal.decorators import check_api_key
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
-    plot_autoscale,
     is_valid_axes_count,
+    plot_autoscale,
 )
 from openbb_terminal.rich_config import console
 
@@ -32,7 +31,7 @@ def display_fundamental_metric_from_project_over_time(
     metric: str,
     project: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Plots fundamental metric from a project over time [Source: Token Terminal]
@@ -108,7 +107,9 @@ def display_fundamental_metric_from_project_over_time(
 
 @log_start_end(log=logger)
 @check_api_key(["API_TOKEN_TERMINAL_KEY"])
-def display_description(project: str, export: str = "", sheet_name: str = None):
+def display_description(
+    project: str, export: str = "", sheet_name: Optional[str] = None
+):
     """Prints description from a project [Source: Token Terminal]
 
     Parameters
