@@ -13,12 +13,10 @@ import requests
 from requests.adapters import HTTPAdapter
 from requests.exceptions import HTTPError
 
-from openbb_terminal.cryptocurrency.dataframe_helpers import (
-    prettify_column_names,
-)
 from openbb_terminal import config_terminal as cfg
-from openbb_terminal.rich_config import console
+from openbb_terminal.cryptocurrency.dataframe_helpers import prettify_column_names
 from openbb_terminal.decorators import check_api_key, log_start_end
+from openbb_terminal.rich_config import console
 
 logger = logging.getLogger(__name__)
 
