@@ -3,17 +3,15 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from openbb_terminal.cryptocurrency.dataframe_helpers import (
     lambda_very_long_number_formatter,
-)
-from openbb_terminal.cryptocurrency.dataframe_helpers import (
     prettify_column_names,
 )
 from openbb_terminal.cryptocurrency.onchain import bitquery_model
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
-from openbb_terminal.decorators import check_api_key
 
 logger = logging.getLogger(__name__)
 
@@ -28,7 +26,7 @@ def display_dex_trades(
     sortby: str = "tradeAmount",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing Trades on Decentralized Exchanges aggregated by DEX or Month
     [Source: https://graphql.bitquery.io/]
@@ -94,7 +92,7 @@ def display_daily_volume_for_given_pair(
     sortby: str = "date",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing daily volume for given pair
     [Source: https://graphql.bitquery.io/]
@@ -169,7 +167,7 @@ def display_dex_volume_for_token(
     sortby: str = "tradeAmount",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing token volume on different Decentralized Exchanges.
     [Source: https://graphql.bitquery.io/]
@@ -235,7 +233,7 @@ def display_ethereum_unique_senders(
     sortby: str = "date",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing number of unique ethereum addresses which made a transaction in given time interval
     [Source: https://graphql.bitquery.io/]
@@ -298,7 +296,7 @@ def display_most_traded_pairs(
     sortby: str = "tradeAmount",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing most traded crypto pairs on given decentralized exchange in chosen time period.
     [Source: https://graphql.bitquery.io/]
@@ -360,7 +358,7 @@ def display_spread_for_crypto_pair(
     sortby: str = "date",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints table showing an average bid and ask prices, average spread for given crypto pair for chosen
     time period. [Source: https://graphql.bitquery.io/]
