@@ -3,13 +3,13 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from openbb_terminal.cryptocurrency.dataframe_helpers import (
     lambda_very_long_number_formatter,
 )
 from openbb_terminal.cryptocurrency.onchain import ethplorer_model
-from openbb_terminal.decorators import check_api_key
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
 from openbb_terminal.rich_config import console
 
@@ -25,7 +25,7 @@ def display_address_info(
     sortby: str = "index",
     ascend: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display info about tokens for given ethereum blockchain balance e.g. ETH balance,
     balance of all tokens with name and symbol. [Source: Ethplorer]
@@ -75,7 +75,7 @@ def display_top_tokens(
     sortby: str = "rank",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display top ERC20 tokens [Source: Ethplorer]
 
@@ -122,7 +122,7 @@ def display_top_token_holders(
     sortby: str = "balance",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display info about top ERC20 token holders. [Source: Ethplorer]
 
@@ -168,7 +168,7 @@ def display_address_history(
     sortby: str = "timestamp",
     ascend: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display information about balance historical transactions. [Source: Ethplorer]
 
@@ -216,7 +216,7 @@ def display_token_info(
     address: str,
     social: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display info about ERC20 token. [Source: Ethplorer]
 
@@ -260,7 +260,7 @@ def display_token_info(
 def display_tx_info(
     tx_hash: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display info about transaction. [Source: Ethplorer]
 
@@ -298,7 +298,7 @@ def display_token_history(
     ascend: bool = False,
     hash_: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display info about token history. [Source: Ethplorer]
 
@@ -357,7 +357,7 @@ def display_token_historical_prices(
     sortby: str = "date",
     ascend: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display token historical prices with volume and market cap, and average price.
     [Source: Ethplorer]
