@@ -1,15 +1,15 @@
 """Shroom model"""
-import logging
-from typing import List
 import json
+import logging
 import time
+from typing import List
+
 import pandas as pd
 
-
-from openbb_terminal.rich_config import console
-from openbb_terminal.decorators import log_start_end, check_api_key
 from openbb_terminal import config_terminal as cfg
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import request
+from openbb_terminal.rich_config import console
 
 logger = logging.getLogger(__name__)
 
