@@ -3,15 +3,15 @@ __docformat__ = "numpy"
 
 import logging
 import textwrap
-from typing import Optional, Tuple, Any
+from typing import Any, Optional, Tuple
 
 import numpy as np
 import pandas as pd
 
-from openbb_terminal.helper_funcs import request
 import openbb_terminal.config_terminal as cfg
-from openbb_terminal.rich_config import console
 from openbb_terminal.decorators import check_api_key, log_start_end
+from openbb_terminal.helper_funcs import request
+from openbb_terminal.rich_config import console
 
 logger = logging.getLogger(__name__)
 
