@@ -4,14 +4,20 @@ __docformat__ = "numpy"
 import logging
 import os
 from typing import List, Optional
+
 import squarify
-from matplotlib import pyplot as plt
-from matplotlib import ticker
-from matplotlib import cm
+from matplotlib import (
+    cm,
+    pyplot as plt,
+    ticker,
+)
 from pandas.plotting import register_matplotlib_converters
-from openbb_terminal import config_terminal as cfg
+
 import openbb_terminal.cryptocurrency.overview.pycoingecko_model as gecko
-from openbb_terminal import feature_flags as obbff
+from openbb_terminal import (
+    config_terminal as cfg,
+    feature_flags as obbff,
+)
 from openbb_terminal.config_plot import PLOT_DPI
 from openbb_terminal.cryptocurrency.dataframe_helpers import (
     lambda_long_number_format_with_type_check,
@@ -19,9 +25,9 @@ from openbb_terminal.cryptocurrency.dataframe_helpers import (
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
+    is_valid_axes_count,
     plot_autoscale,
     print_rich_table,
-    is_valid_axes_count,
 )
 from openbb_terminal.rich_config import console
 
@@ -37,7 +43,7 @@ def display_crypto_heatmap(
     category: str = "",
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Shows cryptocurrencies heatmap [Source: CoinGecko]
@@ -140,7 +146,7 @@ def display_holdings_overview(
     symbol: str,
     show_bar: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     limit: int = 15,
 ) -> None:
     """Shows overview of public companies that holds ethereum or bitcoin. [Source: CoinGecko]
@@ -213,7 +219,7 @@ def display_exchange_rates(
     ascend: bool = False,
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Shows  list of crypto, fiats, commodity exchange rates. [Source: CoinGecko]
 
@@ -252,7 +258,7 @@ def display_exchange_rates(
 
 @log_start_end(log=logger)
 def display_global_market_info(
-    pie: bool = False, export: str = "", sheet_name: str = None
+    pie: bool = False, export: str = "", sheet_name: Optional[str] = None
 ) -> None:
     """Shows global statistics about crypto. [Source: CoinGecko]
         - market cap change
@@ -317,7 +323,9 @@ def display_global_market_info(
 
 
 @log_start_end(log=logger)
-def display_global_defi_info(export: str = "", sheet_name: str = None) -> None:
+def display_global_defi_info(
+    export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Shows global statistics about Decentralized Finances. [Source: CoinGecko]
 
     Parameters
@@ -351,7 +359,7 @@ def display_global_defi_info(export: str = "", sheet_name: str = None) -> None:
 def display_stablecoins(
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     sortby: str = "Market_Cap_[$]",
     ascend: bool = False,
     pie: bool = True,
@@ -438,7 +446,7 @@ def display_categories(
     sortby: str = "market_cap_desc",
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     pie: bool = False,
 ) -> None:
     """Shows top cryptocurrency categories by market capitalization
@@ -510,7 +518,7 @@ def display_exchanges(
     limit: int = 15,
     links: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Shows list of top exchanges from CoinGecko. [Source: CoinGecko]
 
@@ -560,7 +568,7 @@ def display_platforms(
     ascend: bool = True,
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Shows list of financial platforms. [Source: CoinGecko]
 
@@ -603,7 +611,7 @@ def display_products(
     ascend: bool = False,
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Shows list of financial products. [Source: CoinGecko]
 
@@ -646,7 +654,7 @@ def display_indexes(
     ascend: bool = True,
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Shows list of crypto indexes. [Source: CoinGecko]
 
@@ -688,7 +696,7 @@ def display_derivatives(
     ascend: bool = False,
     limit: int = 15,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Shows  list of crypto derivatives. [Source: CoinGecko]
 
