@@ -26,9 +26,9 @@ register_matplotlib_converters()
 @log_start_end(log=logger)
 def show_options(
     datasets: Dict[str, pd.DataFrame],
-    dataset_name: str = None,
+    dataset_name: Optional[str] = None,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Plot custom data
 
@@ -71,7 +71,7 @@ def show_options(
 def display_plot(
     data: Union[pd.Series, pd.DataFrame, Dict[str, pd.DataFrame]],
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.axes]] = None,
 ):
     """Plot data from a dataset
@@ -140,7 +140,7 @@ def display_norm(
     column: str = "",
     plot: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.axes]] = None,
 ):
     """Determine the normality of a timeseries.
@@ -213,7 +213,7 @@ def display_root(
     fuller_reg: str = "c",
     kpss_reg: str = "c",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Determine the normality of a timeseries.
 
@@ -266,7 +266,7 @@ def display_granger(
     lags: int = 3,
     confidence_level: float = 0.05,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Show granger tests
 
@@ -334,7 +334,7 @@ def display_cointegration_test(
     significant: bool = False,
     plot: bool = True,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.axes]] = None,
 ):
     """Estimates long-run and short-run cointegration relationship for series y and x and apply
