@@ -4,17 +4,17 @@ __docformat__ = "numpy"
 
 import logging
 import warnings
-from typing import Union, Optional, List, Tuple
+from typing import List, Optional, Tuple, Union
 
 import pandas as pd
-
 from darts import TimeSeries
 from darts.models import BlockRNNModel
 from darts.models.forecasting.torch_forecasting_model import GlobalForecastingModel
 from darts.utils.likelihood_models import GaussianLikelihood
+
+from openbb_terminal.core.config.paths import USER_FORECAST_MODELS_DIRECTORY
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.forecast import helpers
-from openbb_terminal.core.config.paths import USER_FORECAST_MODELS_DIRECTORY
 
 logger = logging.getLogger(__name__)
 
@@ -25,7 +25,7 @@ def get_brnn_data(
     target_column: str = "close",
     n_predict: int = 5,
     train_split: float = 0.85,
-    past_covariates: str = None,
+    past_covariates: Optional[str] = None,
     forecast_horizon: int = 5,
     input_chunk_length: int = 14,
     output_chunk_length: int = 5,
@@ -38,6 +38,7 @@ def get_brnn_data(
     model_save_name: str = "brnn_model",
     force_reset: bool = True,
     save_checkpoints: bool = True,
+    metric: str = "mape",
 ) -> Tuple[
     Optional[List[TimeSeries]],
     Optional[List[TimeSeries]],
@@ -84,6 +85,8 @@ def get_brnn_data(
         discarded). Defaults to True.
     save_checkpoints: bool
         Whether or not to automatically save the untrained model and checkpoints from training. Defaults to True.
+    metric: str
+        Metric to use for model selection. Defaults to "mape".
 
     Returns
     -------
@@ -174,4 +177,5 @@ def get_brnn_data(
         train_split,
         forecast_horizon,
         n_predict,
+        metric,
     )
