@@ -3,27 +3,20 @@ __docformat__ = "numpy"
 
 import logging
 import os
-from typing import Dict, Optional, List
+from typing import Dict, List, Optional
 
 import matplotlib.pyplot as plt
 import pandas as pd
-from pandas.plotting import register_matplotlib_converters
 import seaborn as sns
 from darts.utils.statistics import plot_acf
+from pandas.plotting import register_matplotlib_converters
 
 from openbb_terminal.config_plot import PLOT_DPI
-from openbb_terminal.decorators import log_start_end
-from openbb_terminal.helper_funcs import (
-    export_data,
-    plot_autoscale,
-)
-from openbb_terminal.helper_funcs import (
-    print_rich_table,
-)
-from openbb_terminal.rich_config import console
-from openbb_terminal.forecast import forecast_model
 from openbb_terminal.config_terminal import theme
-from openbb_terminal.forecast import helpers
+from openbb_terminal.decorators import log_start_end
+from openbb_terminal.forecast import forecast_model, helpers
+from openbb_terminal.helper_funcs import export_data, plot_autoscale, print_rich_table
+from openbb_terminal.rich_config import console
 
 logger = logging.getLogger(__name__)
 
@@ -33,9 +26,9 @@ register_matplotlib_converters()
 @log_start_end(log=logger)
 def show_options(
     datasets: Dict[str, pd.DataFrame],
-    dataset_name: str = None,
+    dataset_name: Optional[str] = None,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Plot custom data
 
@@ -79,7 +72,7 @@ def display_plot(
     data: pd.DataFrame,
     columns: List[str],
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.axes]] = None,
 ):
     """Plot data from a dataset
@@ -129,7 +122,7 @@ def display_seasonality(
     data: pd.DataFrame,
     column: str = "close",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     m: Optional[int] = None,
     max_lag: int = 24,
     alpha: float = 0.05,
@@ -186,7 +179,7 @@ def display_seasonality(
 def display_corr(
     dataset: pd.DataFrame,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.axes]] = None,
 ):
     """Plot correlation coefficients for dataset features
@@ -254,8 +247,25 @@ def show_df(
     limit_col: int = 10,
     name: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
+    """Show a dataframe in a table
+
+    Parameters
+    ----------
+    data: pd.DataFrame
+        The dataframe to show
+    limit: int
+        The number of rows to show
+    limit_col: int
+        The number of columns to show
+    name: str
+        The name of the dataframe
+    export: str
+        Format to export data
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
+    """
     console.print(
         f"[green]{name} dataset has shape (row, column): {data.shape}\n[/green]"
     )
@@ -284,8 +294,24 @@ def show_df(
 
 @log_start_end(log=logger)
 def describe_df(
-    data: pd.DataFrame, name: str = "", export: str = "", sheet_name: str = None
+    data: pd.DataFrame,
+    name: str = "",
+    export: str = "",
+    sheet_name: Optional[str] = None,
 ):
+    """Show descriptive statistics for a dataframe
+
+    Parameters
+    ----------
+    data: pd.DataFrame
+        The dataframe to show
+    name: str
+        The name of the dataframe
+    export: str
+        Format to export data
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
+    """
     new_df = forecast_model.describe_df(data)
     print_rich_table(
         new_df,
@@ -304,8 +330,22 @@ def describe_df(
 
 @log_start_end(log=logger)
 def export_df(
-    data: pd.DataFrame, export: str, name: str = "", sheet_name: str = None
+    data: pd.DataFrame, export: str, name: str = "", sheet_name: Optional[str] = None
 ) -> None:
+    """Export a dataframe to a file
+
+    Parameters
+    ----------
+    data: pd.DataFrame
+        The dataframe to export
+    export: str
+        The format to export the dataframe to
+    name: str
+        The name of the dataframe
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
+    """
+
     export_data(
         export,
         os.path.dirname(os.path.abspath(__file__)),
