@@ -2,15 +2,14 @@
 __docformat__ = "numpy"
 
 import logging
-from typing import Union, List, Optional
 from datetime import datetime
+from typing import List, Optional, Union
 
-import pandas as pd
 import matplotlib.pyplot as plt
+import pandas as pd
 
-from openbb_terminal.forecast import regr_model
 from openbb_terminal.decorators import log_start_end
-from openbb_terminal.forecast import helpers
+from openbb_terminal.forecast import helpers, regr_model
 
 logger = logging.getLogger(__name__)
 # pylint: disable=too-many-arguments
@@ -22,13 +21,13 @@ def display_regression(
     target_column: str = "close",
     dataset_name: str = "",
     n_predict: int = 5,
-    past_covariates: str = None,
+    past_covariates: Optional[str] = None,
     train_split: float = 0.85,
     forecast_horizon: int = 5,
     output_chunk_length: int = 5,
     lags: Union[int, List[int]] = 14,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     residuals: bool = False,
     forecast_only: bool = False,
     start_date: Optional[datetime] = None,
@@ -36,6 +35,7 @@ def display_regression(
     naive: bool = False,
     explainability_raw: bool = False,
     export_pred_raw: bool = False,
+    metric: str = "mape",
     external_axes: Optional[List[plt.axes]] = None,
 ):
     """Display Regression Forecasting
@@ -75,6 +75,8 @@ def display_regression(
     naive: bool
         Whether to show the naive baseline. This just assumes the closing price will be the same
         as the previous day's closing price. Defaults to False.
+    metric: str
+        The metric to use for the forecast. Defaults to "mape".
     external_axes: Optional[List[plt.axes]]
         External axes to plot on
     """
@@ -101,6 +103,7 @@ def display_regression(
         forecast_horizon=forecast_horizon,
         output_chunk_length=output_chunk_length,
         lags=lags,
+        metric=metric,
     )
     probabilistic = False
     helpers.plot_forecast(
@@ -121,6 +124,7 @@ def display_regression(
         forecast_only=forecast_only,
         naive=naive,
         export_pred_raw=export_pred_raw,
+        metric=metric,
         external_axes=external_axes,
     )
     if residuals:
