@@ -5,19 +5,24 @@ __docformat__ = "numpy"
 
 import argparse
 import logging
-from typing import Dict, List
+from typing import Dict, List, Optional
 
-from tqdm import tqdm
-
-from openbb_terminal import feature_flags as obbff, keys_view
-from openbb_terminal import keys_model
-from openbb_terminal.core.config.paths import USER_ENV_FILE
+from openbb_terminal import (
+    feature_flags as obbff,
+    keys_model,
+    keys_view,
+)
 from openbb_terminal.custom_prompt_toolkit import NestedCompleter
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import EXPORT_ONLY_RAW_DATA_ALLOWED
 from openbb_terminal.menu import session
 from openbb_terminal.parent_classes import BaseController
-from openbb_terminal.rich_config import console, MenuText, translate
+from openbb_terminal.rich_config import (
+    MenuText,
+    console,
+    optional_rich_track,
+    translate,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -33,13 +38,11 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
 
     def __init__(
         self,
-        queue: List[str] = None,
+        queue: Optional[List[str]] = None,
         menu_usage: bool = True,
-        env_file: str = str(USER_ENV_FILE),
     ):
         """Constructor"""
         super().__init__(queue)
-        self.env_file = env_file
         if menu_usage:
             if session and obbff.USE_PROMPT_TOOLKIT:
                 choices: dict = {c: {} for c in self.controller_choices}
@@ -50,8 +53,15 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
 
     def check_keys_status(self) -> None:
         """Check keys status"""
-        for api in tqdm(self.API_LIST, desc="Checking keys status"):
-            self.status_dict[api] = getattr(keys_model, "check_" + str(api) + "_key")()
+        for api in optional_rich_track(self.API_LIST, desc="Checking keys status"):
+            if api == "openbb":
+                self.status_dict[api] = getattr(
+                    keys_model, "check_" + str(api) + "_personal_access_token"
+                )()
+            else:
+                self.status_dict[api] = getattr(
+                    keys_model, "check_" + str(api) + "_key"
+                )()
 
     def print_help(self):
         """Print help"""
@@ -133,7 +143,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://www.alphavantage.co/support/#api-key\n"
+                "For your API Key, visit: https://www.alphavantage.co/support/#api-key"
             )
             return
 
@@ -162,9 +172,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print(
-                "For your API Key, visit: https://financialmodelingprep.com\n"
-            )
+            console.print("For your API Key, visit: https://financialmodelingprep.com")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -192,7 +200,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://www.quandl.com\n")
+            console.print("For your API Key, visit: https://www.quandl.com")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -220,7 +228,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://polygon.io\n")
+            console.print("For your API Key, visit: https://polygon.io")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -231,6 +239,36 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
                 key=ns_parser.key, persist=True, show_output=True
             )
 
+    @log_start_end(log=logger)
+    def call_intrinio(self, other_args: List[str]):
+        """Process polygon command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="intrinio",
+            description="Set Intrinio API key.",
+        )
+        parser.add_argument(
+            "-k",
+            "--key",
+            type=str,
+            dest="key",
+            help="key",
+        )
+        if not other_args:
+            console.print(
+                "For your API Key, sign up for a subscription: https://intrinio.com/starter-plan\n"
+            )
+            return
+
+        if other_args and "-" not in other_args[0][0]:
+            other_args.insert(0, "-k")
+        ns_parser = self.parse_simple_args(parser, other_args)
+        if ns_parser:
+            self.status_dict["intrinio"] = keys_model.set_intrinio_key(
+                key=ns_parser.key, persist=True, show_output=True
+            )
+
     @log_start_end(log=logger)
     def call_fred(self, other_args: List[str]):
         """Process FRED command"""
@@ -248,7 +286,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://fred.stlouisfed.org\n")
+            console.print("For your API Key, visit: https://fred.stlouisfed.org")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -276,7 +314,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://newsapi.org\n")
+            console.print("For your API Key, visit: https://newsapi.org")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -304,7 +342,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://developer.tradier.com\n")
+            console.print("For your API Key, visit: https://developer.tradier.com")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -332,7 +370,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://coinmarketcap.com\n")
+            console.print("For your API Key, visit: https://coinmarketcap.com")
             return
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-k")
@@ -359,7 +397,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://finnhub.io\n")
+            console.print("For your API Key, visit: https://finnhub.io")
             return
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-k")
@@ -369,33 +407,6 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
                 key=ns_parser.key, persist=True, show_output=True
             )
 
-    @log_start_end(log=logger)
-    def call_iex(self, other_args: List[str]):
-        """Process iex command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="iex",
-            description="Set IEX Cloud API key.",
-        )
-        parser.add_argument(
-            "-k",
-            "--key",
-            type=str,
-            dest="key",
-            help="key",
-        )
-        if not other_args:
-            console.print("For your API Key, visit: https://iexcloud.io\n")
-            return
-        if other_args and "-" not in other_args[0][0]:
-            other_args.insert(0, "-k")
-        ns_parser = self.parse_simple_args(parser, other_args)
-        if ns_parser:
-            self.status_dict["iex"] = keys_model.set_iex_key(
-                key=ns_parser.key, persist=True, show_output=True
-            )
-
     @log_start_end(log=logger)
     def call_reddit(self, other_args: List[str]):
         """Process reddit command"""
@@ -447,7 +458,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             nargs="+",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://www.reddit.com\n")
+            console.print("For your API Key, visit: https://www.reddit.com")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
         if ns_parser:
@@ -500,7 +511,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             required="-h" not in other_args,
         )
         if not other_args:
-            console.print("For your API Key, visit: https://developer.twitter.com\n")
+            console.print("For your API Key, visit: https://developer.twitter.com")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
         if ns_parser:
@@ -536,7 +547,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="password",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://robinhood.com/us/en/\n")
+            console.print("For your API Key, visit: https://robinhood.com/us/en/")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
         if ns_parser:
@@ -581,7 +592,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             default="",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://www.degiro.fr\n")
+            console.print("For your API Key, visit: https://www.degiro.fr")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
         if ns_parser:
@@ -624,7 +635,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="account type ('live' or 'practice')",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://developer.oanda.com\n")
+            console.print("For your API Key, visit: https://developer.oanda.com")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
         if ns_parser:
@@ -662,7 +673,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             required="-h" not in other_args,
         )
         if not other_args:
-            console.print("For your API Key, visit: https://binance.com\n")
+            console.print("For your API Key, visit: https://binance.com")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
         if ns_parser:
@@ -690,7 +701,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://bitquery.io/\n")
+            console.print("For your API Key, visit: https://bitquery.io/")
             return
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-k")
@@ -700,33 +711,6 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
                 key=ns_parser.key, persist=True, show_output=True
             )
 
-    @log_start_end(log=logger)
-    def call_si(self, other_args: List[str]):
-        """Process si command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="si",
-            description="Set Sentiment Investor API key.",
-        )
-        parser.add_argument(
-            "-k",
-            "--key",
-            type=str,
-            dest="key",
-            help="key",
-        )
-        if not other_args:
-            console.print("For your API Key, visit: https://sentimentinvestor.com\n")
-            return
-        if other_args and "-" not in other_args[0][0]:
-            other_args.insert(0, "-k")
-        ns_parser = self.parse_simple_args(parser, other_args)
-        if ns_parser:
-            self.status_dict["si"] = keys_model.set_si_key(
-                key=ns_parser.key, persist=True, show_output=True
-            )
-
     @log_start_end(log=logger)
     def call_coinbase(self, other_args: List[str]):
         """Process coinbase command"""
@@ -761,7 +745,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             required="-h" not in other_args,
         )
         if not other_args:
-            console.print("For your API Key, visit: https://docs.pro.coinbase.com/\n")
+            console.print("For your API Key, visit: https://docs.pro.coinbase.com/")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
         if ns_parser:
@@ -790,7 +774,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://docs.whale-alert.io/\n")
+            console.print("For your API Key, visit: https://docs.whale-alert.io/")
             return
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-k")
@@ -818,7 +802,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://docs.glassnode.com/basic-api/api-key#how-to-get-an-api-key/\n"
+                "For your API Key, visit: https://docs.glassnode.com/basic-api/api-key#how-to-get-an-api-key/"
             )
             return
         if other_args and "-" not in other_args[0][0]:
@@ -847,7 +831,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://coinglass.github.io/API-Reference/#api-key\n"
+                "For your API Key, visit: https://coinglass.github.io/API-Reference/#api-key"
             )
             return
         if other_args and "-" not in other_args[0][0]:
@@ -876,7 +860,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://cryptopanic.com/developers/api/\n"
+                "For your API Key, visit: https://cryptopanic.com/developers/api/"
             )
             return
         if other_args and "-" not in other_args[0][0]:
@@ -905,7 +889,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://github.com/EverexIO/Ethplorer/wiki/Ethplorer-API\n"
+                "For your API Key, visit: https://github.com/EverexIO/Ethplorer/wiki/Ethplorer-API"
             )
             return
         if other_args and "-" not in other_args[0][0]:
@@ -942,7 +926,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             required="-h" not in other_args,
         )
         if not other_args:
-            console.print("For your API Key, visit: https://www.smartstake.io\n")
+            console.print("For your API Key, visit: https://www.smartstake.io")
             return
         ns_parser = self.parse_simple_args(parser, other_args)
 
@@ -972,7 +956,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://docs.github.com/en/rest/guides/getting-started-with-the-rest-api\n"
+                "For your API Key, visit: https://docs.github.com/en/rest/guides/getting-started-with-the-rest-api"
             )
             return
 
@@ -1001,7 +985,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://messari.io/api/docs\n")
+            console.print("For your API Key, visit: https://messari.io/api/docs")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -1030,7 +1014,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://eodhistoricaldata.com/r/?ref=869U7F4J\n"
+                "For your API Key, visit: https://eodhistoricaldata.com/r/?ref=869U7F4J"
             )
             return
         if other_args and "-" not in other_args[0][0]:
@@ -1060,7 +1044,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         if not other_args:
             console.print(
                 "For your API Key, visit: "
-                "https://academy.santiment.net/products-and-plans/create-an-api-key\n"
+                "https://academy.santiment.net/products-and-plans/create-an-api-key"
             )
             return
         if other_args and "-" not in other_args[0][0]:
@@ -1089,7 +1073,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, visit: https://sdk.flipsidecrypto.xyz/shroomdk\n"
+                "For your API Key, visit: https://sdk.flipsidecrypto.xyz/shroomdk"
             )
             return
 
@@ -1118,7 +1102,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             help="key",
         )
         if not other_args:
-            console.print("For your API Key, visit: https://tokenterminal.com/\n")
+            console.print("For your API Key, visit: https://tokenterminal.com/")
             return
 
         if other_args and "-" not in other_args[0][0]:
@@ -1147,7 +1131,7 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
         )
         if not other_args:
             console.print(
-                "For your API Key, https://stocksera.pythonanywhere.com/accounts/developers\n"
+                "For your API Key, https://stocksera.pythonanywhere.com/accounts/developers"
             )
             return
 
@@ -1158,3 +1142,31 @@ class KeysController(BaseController):  # pylint: disable=too-many-public-methods
             self.status_dict["stocksera"] = keys_model.set_stocksera_key(
                 key=ns_parser.key, persist=True, show_output=True
             )
+
+    @log_start_end(log=logger)
+    def call_openbb(self, other_args: List[str]):
+        """Process openbb command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="openbb",
+            description="Set OpenBB Personal Access Token. ",
+        )
+        parser.add_argument(
+            "-k",
+            "--key",
+            type=str,
+            dest="key",
+            help="key",
+        )
+        if not other_args:
+            console.print("For your Personal Access Token, visit: https://openbb.co/")
+            return
+
+        if other_args and "-" not in other_args[0][0]:
+            other_args.insert(0, "-k")
+        ns_parser = self.parse_simple_args(parser, other_args)
+        if ns_parser:
+            self.status_dict["openbb"] = keys_model.set_openbb_personal_access_token(
+                key=ns_parser.key, persist=True, show_output=True
+            )
