@@ -3,8 +3,9 @@ __docformat__ = "numpy"
 
 import logging
 import os
-from openbb_terminal import keys_model
+from typing import Optional
 
+from openbb_terminal import keys_model
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
 from openbb_terminal.rich_config import console
@@ -13,7 +14,9 @@ logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
-def display_keys(show: bool = False, export: str = "", sheet_name: str = None):
+def display_keys(
+    show: bool = False, export: str = "", sheet_name: Optional[str] = None
+):
     """Display currently set API keys.
 
     Parameters
