@@ -5,32 +5,23 @@ import argparse
 import logging
 import os
 from datetime import datetime, timedelta
-from typing import List
+from typing import List, Optional
 
-import investpy
 import pandas as pd
 
-from openbb_terminal.custom_prompt_toolkit import NestedCompleter
-
 from openbb_terminal import feature_flags as obbff
+from openbb_terminal.custom_prompt_toolkit import NestedCompleter
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
-    EXPORT_BOTH_RAW_DATA_AND_FIGURES,
     EXPORT_ONLY_FIGURES_ALLOWED,
-    EXPORT_ONLY_RAW_DATA_ALLOWED,
-    check_non_negative_float,
     check_positive,
     valid_date,
 )
 from openbb_terminal.menu import session
-from openbb_terminal.mutual_funds import (
-    investpy_model,
-    investpy_view,
-    yfinance_view,
-    avanza_view,
-)
+from openbb_terminal.mutual_funds import avanza_view, mstarpy_view
+from openbb_terminal.mutual_funds.mutual_funds_utils import mapping_country
 from openbb_terminal.parent_classes import BaseController
-from openbb_terminal.rich_config import console, MenuText
+from openbb_terminal.rich_config import MenuText, console
 
 logger = logging.getLogger(__name__)
 
@@ -42,80 +33,37 @@ class FundController(BaseController):
         "resources",
         "country",
         "search",
-        "info",
         "load",
         "plot",
         "sector",
-        "equity",
         "alswe",
         "infoswe",
-        "forecast",
+        "holdings",
+        "carbon",
+        "exclusion",
     ]
 
-    fund_countries = investpy.funds.get_fund_countries()
-    search_by_choices = ["name", "issuer", "isin", "symbol"]
-    search_cols = [
-        "country",
-        "name",
-        "symbol",
-        "issuer",
-        "isin",
-        "asset_class",
-        "currency",
-        "underlying",
-    ]
-    focus_choices = ["all", "country", "sector", "holding"]
+    fund_countries = list(mapping_country.keys())
     PATH = "/funds/"
     FILE_PATH = os.path.join(os.path.dirname(__file__), "README.md")
+    CHOICES_GENERATION = True
 
-    def __init__(self, queue: List[str] = None):
+    def __init__(self, queue: Optional[List[str]] = None):
         """Constructor"""
         super().__init__(queue)
 
-        self.country = "united states"
-        self.data = pd.DataFrame()
+        self.country = "united_states"
+        self.funds_loaded = None
         self.fund_name = ""
         self.fund_symbol = ""
+        self.fund_isin = ""
         self.TRY_RELOAD = True
+        self.end_date = ""
+        self.start_date = ""
 
         if session and obbff.USE_PROMPT_TOOLKIT:
-            choices: dict = {c: {} for c in self.controller_choices}
-
-            one_to_hundred: dict = {str(c): {} for c in range(1, 100)}
-            choices["country"] = {c: {} for c in self.fund_countries}
-            choices["overview"] = {
-                "--limit": None,
-                "-l": "--limit",
-            }
-            choices["search"] = {
-                "--by": {c: {} for c in self.search_by_choices},
-                "-b": "--by",
-                "--fund": None,
-                "--sortby": {c: None for c in self.search_cols},
-                "-s": "--sortby",
-                "--limit": None,
-                "-l": "--limit",
-                "--reverse": {},
-                "-r": "--reverse",
-            }
-            choices["load"] = {
-                "--fund": None,
-                "--name": {},
-                "-n": "--name",
-                "--start": None,
-                "-s": "--start",
-                "--end": None,
-                "-e": "--end",
-            }
-            choices["sector"] = {
-                "--min": one_to_hundred,
-                "-m": "--min",
-            }
-            choices["alswe"] = {"--focus": {c: {} for c in self.focus_choices}}
-
-            choices["support"] = self.SUPPORT_CHOICES
-            choices["about"] = self.ABOUT_CHOICES
-
+            choices: dict = self.choices_default
+            choices["country"].update({c: {} for c in self.fund_countries})
             self.completer = NestedCompleter.from_nested_dict(choices)
 
     def print_help(self):
@@ -137,328 +85,22 @@ class FundController(BaseController):
         mt.add_raw("\n")
         mt.add_param("_fund", fund_string)
         mt.add_raw("\n")
-        mt.add_cmd("info", self.fund_symbol)
         mt.add_cmd("plot", self.fund_symbol)
-        if self.country == "united states":
-            mt.add_cmd("sector", self.fund_symbol)
-            mt.add_cmd("equity", self.fund_symbol)
-        if self.country == "sweden":
-            mt.add_cmd("alswe", self.fund_symbol)
-            mt.add_cmd("infoswe", self.fund_symbol)
-            mt.add_cmd("forecast", self.fund_symbol)
+        mt.add_cmd("sector", self.fund_symbol)
+        mt.add_cmd("holdings", self.fund_symbol)
+        mt.add_cmd("carbon", self.fund_symbol)
+        mt.add_cmd("exclusion", self.fund_symbol)
+        mt.add_cmd("alswe", self.fund_symbol and self.country == "sweden")
+        mt.add_cmd("infoswe", self.fund_symbol and self.country == "sweden")
+
         console.print(text=mt.menu_text, menu="Mutual Funds")
 
     def custom_reset(self):
         """Class specific component of reset command"""
-        if self.fund_name:
-            return ["funds", f"load {self.fund_name} --name"]
+        if self.fund_symbol and self.country:
+            return ["funds", f"country {self.country}", f"load {self.fund_symbol}"]
         return []
 
-    @log_start_end(log=logger)
-    def call_country(self, other_args: List[str]):
-        """Process country command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="country",
-            description="Set a country for funds",
-        )
-        parser.add_argument(
-            "-n",
-            "--name",
-            type=str,
-            dest="name",
-            nargs="+",
-            help="country to select",
-        )
-        if other_args and "-" not in other_args[0][0]:
-            other_args.insert(0, "-n")
-        ns_parser = self.parse_known_args_and_warn(parser, other_args)
-        if ns_parser:
-            country_candidate = " ".join(ns_parser.name)
-            if country_candidate.lower() in self.fund_countries:
-                self.country = " ".join(ns_parser.name)
-            else:
-                console.print(
-                    f"{country_candidate.lower()} not a valid country to select."
-                )
-        return self.queue
-
-    @log_start_end(log=logger)
-    def call_search(self, other_args: List[str]):
-        """Process country command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="search",
-            description="Search mutual funds in selected country based on selected field.",
-        )
-        parser.add_argument(
-            "-b",
-            "--by",
-            choices=self.search_by_choices,
-            default="name",
-            dest="by",
-            help="Field to search by",
-        )
-        parser.add_argument(
-            "--fund",
-            help="Fund string to search for",
-            dest="fund",
-            type=str,
-            nargs="+",
-            required="-h" not in other_args,
-        )
-        parser.add_argument(
-            "-s",
-            "--sortby",
-            dest="sortby",
-            choices=self.search_cols,
-            help="Column to sort by",
-            default="name",
-        )
-        parser.add_argument(
-            "-l",
-            "--limit",
-            help="Number of search results to show",
-            type=check_positive,
-            dest="limit",
-            default=10,
-        )
-        parser.add_argument(
-            "-r",
-            "--reverse",
-            action="store_true",
-            dest="reverse",
-            default=False,
-            help=(
-                "Data is sorted in descending order by default. "
-                "Reverse flag will sort it in an ascending way. "
-                "Only works when raw data is displayed."
-            ),
-        )
-        if other_args and "-" not in other_args[0][0]:
-            other_args.insert(0, "--fund")
-        ns_parser = self.parse_known_args_and_warn(parser, other_args)
-        if ns_parser:
-            search_string = " ".join(ns_parser.fund)
-            investpy_view.display_search(
-                by=ns_parser.by,
-                value=search_string,
-                country=self.country,
-                limit=ns_parser.limit,
-                sortby=ns_parser.sortby,
-                ascend=ns_parser.reverse,
-            )
-        return self.queue
-
-    @log_start_end(log=logger)
-    def call_overview(self, other_args: List[str]):
-        """Process country command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="overview",
-            description="Show overview of funds from selected country.",
-        )
-        parser.add_argument(
-            "-l",
-            "--limit",
-            help="Number of search results to show",
-            type=check_positive,
-            dest="limit",
-            default=10,
-        )
-        ns_parser = self.parse_known_args_and_warn(
-            parser, other_args, export_allowed=EXPORT_ONLY_RAW_DATA_ALLOWED
-        )
-        if ns_parser:
-            investpy_view.display_overview(
-                self.country, limit=ns_parser.limit, export=ns_parser.export
-            )
-        return self.queue
-
-    @log_start_end(log=logger)
-    def call_info(self, other_args: List[str]):
-        """Process country command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="info",
-            description="Get fund information.",
-        )
-        ns_parser = self.parse_known_args_and_warn(parser, other_args)
-        if ns_parser:
-            if not self.fund_name:
-                console.print(
-                    "No fund loaded.  Please use `load` first to plot.\n", style="bold"
-                )
-                return self.queue
-            investpy_view.display_fund_info(self.fund_name, country=self.country)
-        return self.queue
-
-    @log_start_end(log=logger)
-    def call_load(self, other_args: List[str]):
-        """Process country command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="load",
-            description="Get historical data.",
-        )
-        parser.add_argument(
-            "--fund",
-            help="Fund string to search for",
-            dest="fund",
-            type=str,
-            nargs="+",
-            required="-h" not in other_args,
-        )
-        parser.add_argument(
-            "-n",
-            "--name",
-            action="store_true",
-            default=False,
-            dest="name",
-            help="Flag to indicate name provided instead of symbol.",
-        )
-        # Keeping the date format constant for investpy even though it needs to be reformatted in model
-        parser.add_argument(
-            "-s",
-            "--start",
-            type=valid_date,
-            default=(datetime.now() - timedelta(days=366)).strftime("%Y-%m-%d"),
-            dest="start",
-            help="The starting date (format YYYY-MM-DD) of the fund",
-        )
-        parser.add_argument(
-            "-e",
-            "--end",
-            type=valid_date,
-            default=datetime.now().strftime("%Y-%m-%d"),
-            dest="end",
-            help="The ending date (format YYYY-MM-DD) of the fund",
-        )
-        if other_args and "-" not in other_args[0][0]:
-            other_args.insert(0, "--fund")
-        ns_parser = self.parse_known_args_and_warn(parser, other_args)
-        if ns_parser:
-            parsed_fund = " ".join(ns_parser.fund)
-            (
-                self.data,
-                self.fund_name,
-                self.fund_symbol,
-                self.country,
-            ) = investpy_model.get_fund_historical(
-                name=parsed_fund,
-                by_name=ns_parser.name,
-                country=self.country,
-                start_date=ns_parser.start,
-                end_date=ns_parser.end,
-            )
-            if self.data.empty:
-                console.print(
-                    """No data found.
-Potential errors
-    -- Incorrect country specified
-    -- ISIN supplied instead of symbol
-    -- Name used, but --name flag not passed"""
-                )
-        return self.queue
-
-    @log_start_end(log=logger)
-    def call_plot(self, other_args: List[str]):
-        """Process country command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="plot",
-            description="Plot historical data.",
-        )
-
-        ns_parser = self.parse_known_args_and_warn(
-            parser, other_args, export_allowed=EXPORT_ONLY_FIGURES_ALLOWED
-        )
-        if ns_parser:
-            if not self.fund_symbol:
-                console.print(
-                    "No fund loaded.  Please use `load` first to plot.\n", style="bold"
-                )
-                return self.queue
-            investpy_view.display_historical(
-                self.data, name=self.fund_name, export=ns_parser.export
-            )
-        return self.queue
-
-    @log_start_end(log=logger)
-    def call_sector(self, other_args: List[str]):
-        """Process sector command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="sector",
-            description="Show fund sector weighting.",
-        )
-        parser.add_argument(
-            "-m",
-            "--min",
-            type=check_non_negative_float,
-            dest="min",
-            help="Minimum positive float to display sector",
-            default=5,
-        )
-
-        ns_parser = self.parse_known_args_and_warn(
-            parser, other_args, export_allowed=EXPORT_BOTH_RAW_DATA_AND_FIGURES
-        )
-        if ns_parser:
-            if self.country != "united states":
-                console.print(
-                    "YFinance implementation currently only supports funds from united states"
-                )
-                return self.queue
-            if not self.fund_symbol or not self.fund_name:
-                console.print(
-                    "No fund loaded.  Please use `load` first to plot.\n", style="bold"
-                )
-                return self.queue
-            yfinance_view.display_sector(
-                self.fund_symbol,
-                min_pct_to_display=ns_parser.min,
-                export=ns_parser.export,
-                sheet_name=" ".join(ns_parser.sheet_name)
-                if ns_parser.sheet_name
-                else None,
-            )
-
-        return self.queue
-
-    @log_start_end(log=logger)
-    def call_equity(self, other_args: List[str]):
-        """Process equity command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="equity",
-            description="Show fund equity holdings.",
-        )
-
-        ns_parser = self.parse_known_args_and_warn(parser, other_args)
-        if ns_parser:
-            if self.country != "united states":
-                console.print(
-                    "YFinance implementation currently only supports funds from united states"
-                )
-                return self.queue
-            if not self.fund_symbol or not self.fund_name:
-                console.print(
-                    "No fund loaded.  Please use `load` first to plot.\n", style="bold"
-                )
-                return self.queue
-            yfinance_view.display_equity(self.fund_symbol)
-
-        return self.queue
-
     @log_start_end(log=logger)
     def call_alswe(self, other_args: List[str]):
         """Process alswe command"""
@@ -466,13 +108,14 @@ Potential errors
             add_help=False,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
             prog="alswe",
-            description="Show allocation of a swedish fund.",
+            description="Show allocation of a swedish fund. "
+            "To get a list of available funds, check the file `avanza_fund_ID.csv`.",
         )
         parser.add_argument(
             "--focus",
             dest="focus",
             type=str,
-            choices=self.focus_choices,
+            choices=["all", "country", "sector", "holding"],
             default="all",
             help="The focus of the funds exposure/allocation",
         )
@@ -488,20 +131,14 @@ Potential errors
                     "Avanza implementation currently only supports funds from sweden."
                 )
                 return self.queue
-            if self.fund_name == "":
-                if self.fund_symbol != "":
-                    self.fund_symbol = investpy_model.get_fund_name_from_symbol(
-                        self.fund_symbol
-                    )
-                else:
-                    console.print(
-                        "No fund loaded. Please use `load` first.\n", style="bold"
-                    )
-                    return self.queue
-            if self.fund_name.upper() not in ava_fund.index.str.upper().to_numpy():
-                console.print("No fund data. Please use another fund", style="bold")
+
+            if self.fund_isin not in ava_fund["ISIN"].tolist():
+                console.print("No fund data. Please use another fund.")
                 return self.queue
-            avanza_view.display_allocation(self.fund_name, ns_parser.focus)
+
+            avanza_view.display_allocation(
+                name=self.fund_name, isin=self.fund_isin, focus=ns_parser.focus
+            )
 
         return self.queue
 
@@ -512,7 +149,8 @@ Potential errors
             add_help=False,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
             prog="infoswe",
-            description="Show fund info of a swedish fund.",
+            description="Show fund info of a swedish fund. "
+            "To get a list of available funds, check the file `avanza_fund_ID.csv`.",
         )
 
         ns_parser = self.parse_known_args_and_warn(parser, other_args)
@@ -526,32 +164,276 @@ Potential errors
                     "Avanza implementation currently only supports funds from sweden."
                 )
                 return self.queue
-            if self.fund_name == "":
-                if self.fund_symbol != "":
-                    self.fund_symbol = investpy_model.get_fund_name_from_symbol(
-                        self.fund_symbol
-                    )
-                else:
-                    console.print(
-                        "No fund loaded. Please use `load` first.\n", style="bold"
-                    )
-                    return self.queue
-            if self.fund_name.upper() not in ava_fund.index.str.upper().to_numpy():
-                console.print("No fund data. Please use another fund", style="bold")
+
+            if self.fund_isin not in ava_fund["ISIN"].tolist():
+                console.print("No fund data. Please use another fund.")
                 return self.queue
-            avanza_view.display_info(self.fund_name)
+
+            avanza_view.display_info(self.fund_isin)
 
         return self.queue
 
     @log_start_end(log=logger)
-    def call_forecast(self, _):
-        """Process forecast command"""
-        # pylint: disable=import-outside-toplevel
-        from openbb_terminal.forecast import forecast_controller
-
-        self.queue = self.load_class(
-            forecast_controller.ForecastController,
-            self.fund_name,
-            self.data,
-            self.queue,
+    def call_country(self, other_args: List[str]):
+        """Process country command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="country",
+            description="Set a country for funds",
         )
+        parser.add_argument(
+            "-n",
+            "--name",
+            type=str,
+            choices=self.fund_countries,
+            dest="name",
+            help="country to select",
+            default="",
+        )
+        if other_args and "-" not in other_args[0][0]:
+            other_args.insert(0, "-n")
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+        if ns_parser:
+            country_candidate = ns_parser.name
+            if country_candidate.lower() in self.fund_countries:
+                self.country = country_candidate
+                console.print(f"{country_candidate.title()} selected.")
+            else:
+                console.print(
+                    f'" {country_candidate.title()} " not a valid country to select.'
+                )
+
+        return self.queue
+
+    @log_start_end(log=logger)
+    def call_search(self, other_args: List[str]):
+        """Process search command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="search",
+            description="Search mutual funds in selected country",
+        )
+        parser.add_argument(
+            "--fund",
+            help="Fund string to search for",
+            dest="fund",
+            type=str,
+            required="-h" not in other_args,
+        )
+
+        parser.add_argument(
+            "-l",
+            "--limit",
+            help="Number of search results to show",
+            type=check_positive,
+            dest="limit",
+            default=10,
+        )
+        if other_args and "-" not in other_args[0][0]:
+            other_args.insert(0, "--fund")
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+        if ns_parser:
+            mstarpy_view.display_search(
+                term=ns_parser.fund,
+                country=self.country,
+                limit=ns_parser.limit,
+            )
+        return self.queue
+
+    @log_start_end(log=logger)
+    def call_load(self, other_args: List[str]):
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="load",
+            description="Load the fund to perform analysis on.",
+        )
+        parser.add_argument(
+            "--fund",
+            help="Fund string to search for",
+            dest="fund",
+            type=str,
+            required="-h" not in other_args,
+        )
+        parser.add_argument(
+            "-s",
+            "--start",
+            type=valid_date,
+            default=(datetime.now() - timedelta(days=365)).strftime("%Y-%m-%d"),
+            dest="start",
+            help="The starting date (format YYYY-MM-DD) of the stock",
+        )
+        parser.add_argument(
+            "-e",
+            "--end",
+            type=valid_date,
+            default=datetime.now().strftime("%Y-%m-%d"),
+            dest="end",
+            help="The ending date (format YYYY-MM-DD) of the stock",
+        )
+        if other_args and "-" not in other_args[0][0]:
+            other_args.insert(0, "--fund")
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+        if ns_parser:
+            if not self.country:
+                console.print(
+                    "[yellow]Loading without a country selected "
+                    " might result in unexpected results.[/yellow]"
+                )
+
+            funds_loaded = mstarpy_view.display_load(
+                term=ns_parser.fund, country=self.country
+            )
+
+            if funds_loaded:
+                self.funds_loaded = funds_loaded
+                self.fund_name = funds_loaded.name
+                self.fund_symbol = funds_loaded.code
+                self.fund_isin = funds_loaded.isin
+                self.end_date = ns_parser.end.strftime("%Y-%m-%d")
+                self.start_date = ns_parser.start.strftime("%Y-%m-%d")
+
+                console.print(
+                    f"The fund {self.fund_name} - {self.fund_isin} ({self.fund_symbol})"
+                    " was successfully loaded."
+                )
+
+            else:
+                console.print("No funds were loaded.")
+        return self.queue
+
+    @log_start_end(log=logger)
+    def call_plot(self, other_args: List[str]):
+        """Process plot command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="plot",
+            description="Plot historical data.",
+        )
+        parser.add_argument(
+            "-c",
+            default="",
+            choices=["category", "index", "both"],
+            dest="compare",
+            type=str.lower,
+            help="Compare funds performance with its category or index",
+        )
+        ns_parser = self.parse_known_args_and_warn(
+            parser, other_args, export_allowed=EXPORT_ONLY_FIGURES_ALLOWED
+        )
+        if ns_parser:
+            if not self.fund_symbol:
+                console.print("No fund loaded.  Please use `load` first to plot.")
+                return self.queue
+            mstarpy_view.display_historical(
+                loaded_funds=self.funds_loaded,
+                start_date=datetime.strptime(self.start_date, "%Y-%m-%d"),
+                end_date=datetime.strptime(self.end_date, "%Y-%m-%d"),
+                comparison=ns_parser.compare,
+            )
+        return self.queue
+
+    @log_start_end(log=logger)
+    def call_sector(self, other_args: List[str]):
+        """Process plot command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="sector",
+            description="Show funds, index, category sector breakdown.",
+        )
+        parser.add_argument(
+            "-t",
+            "--type",
+            type=str,
+            choices=["equity", "fixed_income"],
+            dest="type",
+            help="asset type to select",
+            default="equity",
+        )
+        if other_args and "-" not in other_args[0][0]:
+            other_args.insert(0, "-t")
+
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+
+        if ns_parser:
+            if not self.fund_symbol:
+                console.print("No fund loaded.  Please use `load` first.")
+                return self.queue
+
+            mstarpy_view.display_sector(self.funds_loaded, asset_type=ns_parser.type)
+        return self.queue
+
+    @log_start_end(log=logger)
+    def call_holdings(self, other_args: List[str]):
+        """Process holdings command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="holdings",
+            description="Show funds holdings.",
+        )
+        parser.add_argument(
+            "-t",
+            "--type",
+            type=str,
+            choices=["all", "equity", "bond", "other"],
+            dest="type",
+            help="type of holdings",
+            default="all",
+        )
+        if other_args and "-" not in other_args[0][0]:
+            other_args.insert(0, "-t")
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+
+        if ns_parser:
+            if not self.fund_symbol:
+                console.print("No fund loaded.  Please use `load` first.")
+                return self.queue
+
+            mstarpy_view.display_holdings(self.funds_loaded, ns_parser.type)
+
+        return self.queue
+
+    @log_start_end(log=logger)
+    def call_carbon(self, other_args: List[str]):
+        """Process carbon_metrics command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="carbon",
+            description="Show funds carbon metrcis.",
+        )
+
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+        if ns_parser:
+            if not self.fund_symbol:
+                console.print("No fund loaded.  Please use `load` first.")
+                return self.queue
+
+            mstarpy_view.display_carbon_metrics(self.funds_loaded)
+
+        return self.queue
+
+    @log_start_end(log=logger)
+    def call_exclusion(self, other_args: List[str]):
+        """Process exclusion_policy command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="exclusion",
+            description="Show funds exclsuion policy.",
+        )
+
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+        if ns_parser:
+            if not self.fund_symbol:
+                console.print("No fund loaded.  Please use `load` first to plot.")
+                return self.queue
+
+            mstarpy_view.display_exclusion_policy(self.funds_loaded)
+
+        return self.queue
