@@ -3,6 +3,7 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 import matplotlib.pyplot as plt
 import pandas as pd
@@ -10,11 +11,7 @@ import pandas as pd
 from openbb_terminal import feature_flags as obbff
 from openbb_terminal.config_plot import PLOT_DPI
 from openbb_terminal.decorators import log_start_end
-from openbb_terminal.helper_funcs import (
-    export_data,
-    plot_autoscale,
-    print_rich_table,
-)
+from openbb_terminal.helper_funcs import export_data, plot_autoscale, print_rich_table
 from openbb_terminal.mutual_funds import yfinance_model
 from openbb_terminal.rich_config import console
 
@@ -25,7 +22,10 @@ logger = logging.getLogger(__name__)
 
 @log_start_end(log=logger)
 def display_sector(
-    name: str, min_pct_to_display: float = 5, export: str = "", sheet_name: str = None
+    name: str,
+    min_pct_to_display: float = 5,
+    export: str = "",
+    sheet_name: Optional[str] = None,
 ):
     """Display sector weightings for fund
 
