@@ -11,7 +11,7 @@ import os
 import re
 from abc import ABCMeta, abstractmethod
 from datetime import datetime, timedelta
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Optional, Union
 
 import numpy as np
 import pandas as pd
@@ -19,15 +19,16 @@ from prompt_toolkit.formatted_text import HTML
 from prompt_toolkit.styles import Style
 from rich.markdown import Markdown
 
+from openbb_terminal import feature_flags as obbff
+from openbb_terminal.config_terminal import theme
+from openbb_terminal.core.completer.choices import build_controller_choice_map
 from openbb_terminal.core.config.paths import (
     USER_CUSTOM_IMPORTS_DIRECTORY,
     USER_ROUTINES_DIRECTORY,
 )
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.cryptocurrency import cryptocurrency_helpers
 from openbb_terminal.custom_prompt_toolkit import NestedCompleter
-from openbb_terminal.menu import session
-from openbb_terminal import feature_flags as obbff
-from openbb_terminal.config_terminal import theme
+from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     check_file_type_saved,
     check_positive,
@@ -42,11 +43,11 @@ from openbb_terminal.helper_funcs import (
     system_clear,
     valid_date,
 )
+from openbb_terminal.menu import session
 from openbb_terminal.rich_config import console, get_ordered_list_sources
+from openbb_terminal.session.user import User
 from openbb_terminal.stocks import stocks_helper
-from openbb_terminal.terminal_helper import open_openbb_documentation
-from openbb_terminal.cryptocurrency import cryptocurrency_helpers
-from openbb_terminal.core.completer.choices import build_controller_choice_map
+from openbb_terminal.terminal_helper import is_auth_enabled, open_openbb_documentation
 
 logger = logging.getLogger(__name__)
 
@@ -96,6 +97,9 @@ class BaseController(metaclass=ABCMeta):
         "screenshot",
     ]
 
+    if is_auth_enabled():
+        CHOICES_COMMON += ["whoami"]
+
     CHOICES_COMMANDS: List[str] = []
     CHOICES_MENUS: List[str] = []
     SUPPORT_CHOICES: dict = {}
@@ -117,7 +121,7 @@ class BaseController(metaclass=ABCMeta):
 
         return choices
 
-    def __init__(self, queue: List[str] = None) -> None:
+    def __init__(self, queue: Optional[List[str]] = None) -> None:
         """Create the base class for any controller in the codebase.
 
         Used to simplify the creation of menus.
@@ -220,6 +224,15 @@ class BaseController(metaclass=ABCMeta):
             old_class = controllers[class_ins.PATH]
             old_class.queue = self.queue
             return old_class.menu()
+        # Add another case so options data is saved
+        if (
+            class_ins.PATH == "/stocks/options/"
+            and obbff.REMEMBER_CONTEXTS
+            and "/stocks/options/" in controllers
+        ):
+            old_class = controllers[class_ins.PATH]
+            old_class.queue = self.queue
+            return old_class.menu()
         return class_ins(*args, **kwargs).menu()
 
     def save_class(self) -> None:
@@ -275,13 +288,14 @@ class BaseController(metaclass=ABCMeta):
 
     def log_queue(self) -> None:
         """Log command queue."""
-        joined_queue = self.COMMAND_SEPARATOR.join(self.queue)
-        if self.queue and not self.contains_keys(joined_queue):
-            logger.info(
-                "QUEUE: {'path': '%s', 'queue': '%s'}",
-                self.PATH,
-                joined_queue,
-            )
+        if self.queue:
+            joined_queue = self.COMMAND_SEPARATOR.join(self.queue)
+            if not self.contains_keys(joined_queue):
+                logger.info(
+                    "QUEUE: {'path': '%s', 'queue': '%s'}",
+                    self.PATH,
+                    joined_queue,
+                )
 
     def log_cmd_and_queue(
         self, known_cmd: str, other_args_str: str, the_input: str
@@ -371,6 +385,9 @@ class BaseController(metaclass=ABCMeta):
 
         self.log_queue()
 
+        if not self.queue or (self.queue and self.queue[0] not in ("quit", "help")):
+            console.print()
+
         return self.queue
 
     @log_start_end(log=logger)
@@ -661,6 +678,20 @@ class BaseController(metaclass=ABCMeta):
         if ns_parser:
             screenshot()
 
+    @log_start_end(log=logger)
+    def call_whoami(self, other_args: List[str]) -> None:
+        """Process whoami command."""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="whoami",
+            description="Show current user",
+        )
+        ns_parser = self.parse_simple_args(parser, other_args)
+
+        if ns_parser:
+            User.whoami()
+
     @staticmethod
     def parse_simple_args(parser: argparse.ArgumentParser, other_args: List[str]):
         """Parse list of arguments into the supplied parser.
@@ -912,10 +943,9 @@ class BaseController(metaclass=ABCMeta):
 
                 # Process the input command
                 self.queue = self.switch(an_input)
-                if not self.queue or (
-                    self.queue and self.queue[0] not in ("quit", "help")
-                ):
-                    console.print()
+
+                if an_input == "logout":
+                    return ["logout"]
 
             except SystemExit:
                 if not self.contains_keys(an_input):
@@ -1048,15 +1078,6 @@ class StockBaseController(BaseController, metaclass=ABCMeta):
             help="Load weekly data",
             dest="weekly",
         )
-        parser.add_argument(
-            "-r",
-            "--iexrange",
-            dest="iexrange",
-            help="Range for using the iexcloud api.  Longer range requires more tokens in account",
-            choices=["ytd", "1y", "2y", "5y", "6m"],
-            type=str,
-            default="ytd",
-        )
         parser.add_argument(
             "--exchange",
             dest="exchange",
@@ -1144,9 +1165,7 @@ class StockBaseController(BaseController, metaclass=ABCMeta):
                     self.ticker = ns_parser.ticker.upper()
                     self.suffix = ""
 
-                if ns_parser.source == "IEXCloud":
-                    self.start = self.stock.index[0].to_pydatetime()
-                elif ns_parser.source == "EODHD":
+                if ns_parser.source == "EODHD":
                     self.start = self.stock.index[0].to_pydatetime()
                 elif ns_parser.source == "eodhd":
                     self.start = self.stock.index[0].to_pydatetime()
