@@ -1,9 +1,11 @@
-from typing import Dict, List, Tuple
+from typing import Dict, List, Optional, Tuple
+
 import pandas as pd
+
 from openbb_terminal.portfolio.portfolio_optimization import (
     excel_model,
-    optimizer_model,
     optimizer_helper,
+    optimizer_model,
 )
 from openbb_terminal.portfolio.portfolio_optimization.parameters import params_view
 from openbb_terminal.rich_config import console
@@ -14,9 +16,9 @@ class PoEngine:
 
     def __init__(
         self,
-        symbols_categories: Dict[str, Dict[str, str]] = None,
-        symbols_file_path: str = None,
-        parameters_file_path: str = None,
+        symbols_categories: Optional[Dict[str, Dict[str, str]]] = None,
+        symbols_file_path: Optional[str] = None,
+        parameters_file_path: Optional[str] = None,
     ):
         """Initialize the engine
 
@@ -131,7 +133,7 @@ class PoEngine:
 
         return available_categories
 
-    def get_category(self, category: str = None) -> Dict[str, str]:
+    def get_category(self, category: Optional[str] = None) -> Dict[str, str]:
         """Get the category
 
         Parameters
@@ -166,7 +168,7 @@ class PoEngine:
             return {}
         return self._categories
 
-    def get_category_df(self, category: str = None) -> pd.DataFrame:
+    def get_category_df(self, category: Optional[str] = None) -> pd.DataFrame:
         """Get the category df
 
         Returns
