@@ -1,17 +1,22 @@
 """Rich Module"""
 __docformat__ = "numpy"
 
-import os
 import json
+import os
 from pathlib import Path
-from typing import Tuple
+from typing import Iterable, Optional, Tuple, Union
+
+import i18n
 from rich import panel
 from rich.console import Console, Theme
+from rich.progress import track
 from rich.text import Text
-import i18n
+
+from openbb_terminal import (
+    config_terminal as cfg,
+    feature_flags as obbff,
+)
 from openbb_terminal.core.config.paths import MISCELLANEOUS_DIRECTORY
-from openbb_terminal import config_terminal as cfg
-from openbb_terminal import feature_flags as obbff
 
 # pylint: disable=no-member,c-extension-no-member
 
@@ -219,7 +224,7 @@ class MenuText:
 
         self.menu_text += cmd + "\n"
 
-    def add_menu(self, key_menu: str, condition: bool = True):
+    def add_menu(self, key_menu: str, condition: Optional[Union[bool, str]] = True):
         """Append menu text (after translation from key) to a menu
 
         Parameters
@@ -313,5 +318,28 @@ class ConsoleAndPanel:
             else:
                 print(*args, **kwargs)
 
+    def input(self, *args, **kwargs):
+        self.print(*args, **kwargs, end="")
+        return input()
+
 
 console = ConsoleAndPanel()
+
+
+def optional_rich_track(
+    inputs: Iterable, suppress_output: bool = False, desc: str = ""
+):
+    """Generate a rich track progress bar if desired
+
+    Parameters
+    ----------
+    inputs : Iterable
+        The items to be looped through
+    suppress_output : bool, optional
+        Flag to suppress the output, by default False
+    desc : str, optional
+        String to describe the progress bar, by default ""
+    """
+    if suppress_output:
+        return inputs
+    return track(inputs, description=desc)
