@@ -4,12 +4,10 @@ __docformat__ = "numpy"
 import argparse
 import logging
 from datetime import datetime, timedelta
-from typing import List
+from typing import List, Optional
 
 import yfinance as yf
 
-from openbb_terminal.custom_prompt_toolkit import NestedCompleter
-
 from openbb_terminal import feature_flags as obbff
 from openbb_terminal.common.behavioural_analysis import (
     finbrain_view,
@@ -18,7 +16,7 @@ from openbb_terminal.common.behavioural_analysis import (
     stocktwits_view,
     twitter_view,
 )
-from openbb_terminal.stocks.behavioural_analysis import finnhub_view, cramer_view
+from openbb_terminal.custom_prompt_toolkit import NestedCompleter
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     EXPORT_BOTH_RAW_DATA_AND_FIGURES,
@@ -29,7 +27,8 @@ from openbb_terminal.helper_funcs import (
 )
 from openbb_terminal.menu import session
 from openbb_terminal.parent_classes import StockBaseController
-from openbb_terminal.rich_config import console, MenuText
+from openbb_terminal.rich_config import MenuText, console
+from openbb_terminal.stocks.behavioural_analysis import cramer_view, finnhub_view
 
 # pylint:disable=R0904,C0302
 
@@ -73,7 +72,7 @@ class BehaviouralAnalysisController(StockBaseController):
     PATH = "/stocks/ba/"
     CHOICES_GENERATION = True
 
-    def __init__(self, ticker: str, start: datetime, queue: List[str] = None):
+    def __init__(self, ticker: str, start: datetime, queue: Optional[List[str]] = None):
         """Constructor"""
         super().__init__(queue)
 
