@@ -5,25 +5,24 @@ import argparse
 import logging
 import random
 from datetime import datetime, timedelta
-from typing import List
+from typing import List, Optional
 
 import yfinance as yf
 
-from openbb_terminal.custom_prompt_toolkit import NestedCompleter
-
 from openbb_terminal import feature_flags as obbff
+from openbb_terminal.custom_prompt_toolkit import NestedCompleter
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     EXPORT_BOTH_RAW_DATA_AND_FIGURES,
     EXPORT_ONLY_RAW_DATA_ALLOWED,
     check_non_negative,
     check_positive,
-    valid_date,
     check_start_less_than_end,
+    valid_date,
 )
 from openbb_terminal.menu import session
 from openbb_terminal.parent_classes import BaseController
-from openbb_terminal.rich_config import console, MenuText, get_ordered_list_sources
+from openbb_terminal.rich_config import MenuText, console, get_ordered_list_sources
 from openbb_terminal.stocks.comparison_analysis import (
     finbrain_view,
     finnhub_model,
@@ -74,7 +73,9 @@ class ComparisonAnalysisController(BaseController):
     PATH = "/stocks/ca/"
     CHOICES_GENERATION = True
 
-    def __init__(self, similar: List[str] = None, queue: List[str] = None):
+    def __init__(
+        self, similar: Optional[List[str]] = None, queue: Optional[List[str]] = None
+    ):
         """Constructor"""
         super().__init__(queue)
 
