@@ -3,6 +3,7 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
@@ -13,7 +14,9 @@ logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
-def high_short_interest(limit: int = 10, export: str = "", sheet_name: str = None):
+def high_short_interest(
+    limit: int = 10, export: str = "", sheet_name: Optional[str] = None
+):
     """Prints top N high shorted interest stocks from https://www.highshortinterest.com
 
     Parameters
