@@ -4,13 +4,14 @@ __docformat__ = "numpy"
 import logging
 import os
 import re
+from typing import Optional
 
 import pandas as pd
 
+from openbb_terminal import rich_config
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
 from openbb_terminal.stocks.discovery import fidelity_model
-from openbb_terminal import rich_config
 
 logger = logging.getLogger(__name__)
 
@@ -64,7 +65,7 @@ def lambda_price_change_color_red_green(val: str) -> str:
 
 
 @log_start_end(log=logger)
-def orders_view(limit: int = 5, export: str = "", sheet_name: str = None):
+def orders_view(limit: int = 5, export: str = "", sheet_name: Optional[str] = None):
     """Prints last N orders by Fidelity customers. [Source: Fidelity]
 
     Parameters
