@@ -1,8 +1,9 @@
 """NASDAQ DataLink Model"""
 __docformat__ = "numpy"
 
-from datetime import datetime
 import logging
+from datetime import datetime
+from typing import Optional
 
 import pandas as pd
 import requests
@@ -12,7 +13,6 @@ from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import get_user_agent, request
 from openbb_terminal.rich_config import console
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -49,7 +49,7 @@ def get_retail_tickers() -> pd.DataFrame:
 
 
 @log_start_end(log=logger)
-def get_dividend_cal(date: str = None) -> pd.DataFrame:
+def get_dividend_cal(date: Optional[str] = None) -> pd.DataFrame:
     """Gets dividend calendar for given date.  Date represents Ex-Dividend Date
 
     Parameters
