@@ -1,15 +1,15 @@
 """NASDAQ DataLink View"""
 __docformat__ = "numpy"
 
-from datetime import datetime
 import logging
 import os
+from datetime import datetime
+from typing import Optional
 
-from openbb_terminal.decorators import log_start_end
+from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
 from openbb_terminal.rich_config import console
 from openbb_terminal.stocks.discovery import nasdaq_model
-from openbb_terminal.decorators import check_api_key
 
 # pylint: disable=E1123
 
@@ -19,7 +19,9 @@ logger = logging.getLogger(__name__)
 
 @log_start_end(log=logger)
 @check_api_key(["API_KEY_QUANDL"])
-def display_top_retail(limit: int = 3, export: str = "", sheet_name: str = None):
+def display_top_retail(
+    limit: int = 3, export: str = "", sheet_name: Optional[str] = None
+):
     """Display the top 10 retail traded stocks for last days
 
     Parameters
@@ -56,12 +58,12 @@ def display_top_retail(limit: int = 3, export: str = "", sheet_name: str = None)
 
 @log_start_end(log=logger)
 def display_dividend_calendar(
-    date: str = None,
+    date: Optional[str] = None,
     sortby: str = "Dividend",
     ascend: bool = False,
     limit: int = 10,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Display NASDAQ dividend calendar
 
