@@ -3,6 +3,7 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
@@ -12,7 +13,9 @@ logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
-def display_gainers(limit: int = 5, export: str = "", sheet_name: str = None) -> None:
+def display_gainers(
+    limit: int = 5, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Display gainers. [Source: Yahoo Finance]
 
     Parameters
@@ -43,7 +46,9 @@ def display_gainers(limit: int = 5, export: str = "", sheet_name: str = None) ->
 
 
 @log_start_end(log=logger)
-def display_losers(limit: int = 5, export: str = "", sheet_name: str = None) -> None:
+def display_losers(
+    limit: int = 5, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Display losers. [Source: Yahoo Finance]
 
     Parameters
@@ -74,7 +79,9 @@ def display_losers(limit: int = 5, export: str = "", sheet_name: str = None) ->
 
 
 @log_start_end(log=logger)
-def display_ugs(limit: int = 5, export: str = "", sheet_name: str = None) -> None:
+def display_ugs(
+    limit: int = 5, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Display most undervalued growth stock. [Source: Yahoo Finance]
 
     Parameters
@@ -104,7 +111,9 @@ def display_ugs(limit: int = 5, export: str = "", sheet_name: str = None) -> Non
 
 
 @log_start_end(log=logger)
-def display_gtech(limit: int = 5, export: str = "", sheet_name: str = None) -> None:
+def display_gtech(
+    limit: int = 5, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Display growth technology stocks. [Source: Yahoo Finance]
 
     Parameters
@@ -135,7 +144,9 @@ def display_gtech(limit: int = 5, export: str = "", sheet_name: str = None) -> N
 
 
 @log_start_end(log=logger)
-def display_active(limit: int = 5, export: str = "", sheet_name: str = None) -> None:
+def display_active(
+    limit: int = 5, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Display most active stocks. [Source: Yahoo Finance]
 
     Parameters
@@ -166,7 +177,9 @@ def display_active(limit: int = 5, export: str = "", sheet_name: str = None) ->
 
 
 @log_start_end(log=logger)
-def display_ulc(limit: int = 5, export: str = "", sheet_name: str = None) -> None:
+def display_ulc(
+    limit: int = 5, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Display potentially undervalued large cap stocks. [Source: Yahoo Finance]
 
     Parameters
@@ -197,7 +210,9 @@ def display_ulc(limit: int = 5, export: str = "", sheet_name: str = None) -> Non
 
 
 @log_start_end(log=logger)
-def display_asc(limit: int = 5, export: str = "", sheet_name: str = None) -> None:
+def display_asc(
+    limit: int = 5, export: str = "", sheet_name: Optional[str] = None
+) -> None:
     """Display small cap stocks with earnings growth rates better than 25%. [Source: Yahoo Finance]
 
     Parameters
