@@ -6,28 +6,27 @@ import os
 from typing import List, Optional
 
 from matplotlib import pyplot as plt
-from openbb_terminal.config_terminal import theme
+
 from openbb_terminal.config_plot import PLOT_DPI
+from openbb_terminal.config_terminal import theme
 from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import (
-    export_data,
-    print_rich_table,
-    plot_autoscale,
     camel_case_split,
+    export_data,
     is_valid_axes_count,
+    plot_autoscale,
+    print_rich_table,
 )
+from openbb_terminal.helpers_denomination import transform as transform_by_denomination
 from openbb_terminal.rich_config import console
 from openbb_terminal.stocks.fundamental_analysis import av_model
-from openbb_terminal.helpers_denomination import (
-    transform as transform_by_denomination,
-)
 
 logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
 @check_api_key(["API_KEY_ALPHAVANTAGE"])
-def display_overview(symbol: str):
+def display_overview(symbol: str, export: str = "", sheet_name: Optional[str] = None):
     """Alpha Vantage stock ticker overview
 
     Parameters
@@ -47,12 +46,20 @@ def display_overview(symbol: str):
         show_index=True,
     )
 
+    export_data(
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "overview",
+        df_fa,
+        sheet_name,
+    )
+
     console.print(f"Company Description:\n\n{df_fa.loc['Description'][0]}")
 
 
 @log_start_end(log=logger)
 @check_api_key(["API_KEY_ALPHAVANTAGE"])
-def display_key(symbol: str, export: str = "", sheet_name: str = None):
+def display_key(symbol: str, export: str = "", sheet_name: Optional[str] = None):
     """Alpha Vantage key metrics
 
     Parameters
@@ -85,9 +92,9 @@ def display_income_statement(
     limit: int = 5,
     quarterly: bool = False,
     ratios: bool = False,
-    plot: list = None,
+    plot: Optional[list] = None,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Alpha Vantage income statement
 
@@ -176,9 +183,9 @@ def display_balance_sheet(
     limit: int = 5,
     quarterly: bool = False,
     ratios: bool = False,
-    plot: list = None,
+    plot: Optional[list] = None,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Alpha Vantage balance sheet statement
 
@@ -268,9 +275,9 @@ def display_cash_flow(
     limit: int = 5,
     quarterly: bool = False,
     ratios: bool = False,
-    plot: list = None,
+    plot: Optional[list] = None,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Alpha Vantage income statement
 
@@ -358,7 +365,7 @@ def display_earnings(
     limit: int = 5,
     quarterly: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Alpha Vantage earnings
 
@@ -401,7 +408,7 @@ def display_earnings(
 def display_fraud(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     help_text: bool = False,
     color: bool = True,
     detail: bool = False,
@@ -454,7 +461,7 @@ A mckee less than 0.5 indicates a high risk of fraud.
     export_data(
         export,
         os.path.dirname(os.path.abspath(__file__)),
-        "dupont",
+        "fraud",
         df,
         sheet_name,
     )
@@ -467,7 +474,7 @@ def display_dupont(
     symbol: str,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Shows the extended dupont ratio
