@@ -2,17 +2,18 @@
 __docformat__ = "numpy"
 import logging
 import os
+from typing import Optional
 
 import matplotlib.pyplot as plt
 
-from openbb_terminal.config_terminal import theme
 from openbb_terminal.config_plot import PLOT_DPI
+from openbb_terminal.config_terminal import theme
 from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
     lambda_long_number_format,
-    print_rich_table,
     plot_autoscale,
+    print_rich_table,
 )
 from openbb_terminal.stocks.fundamental_analysis import eodhd_model
 
@@ -27,9 +28,9 @@ def display_fundamentals(
     limit: int = 10,
     quarterly: bool = False,
     ratios: bool = False,
-    plot: list = None,
+    plot: Optional[list] = None,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Display tickers balance sheet; income statement; cash flow statement
 
