@@ -2,20 +2,21 @@
 __docformat__ = "numpy"
 
 import logging
-
+import os
+from typing import Optional
 
 from openbb_terminal.decorators import log_start_end
+from openbb_terminal.helper_funcs import export_data, print_rich_table
 from openbb_terminal.rich_config import console
 from openbb_terminal.stocks.fundamental_analysis import seeking_alpha_model
-from openbb_terminal.helper_funcs import (
-    print_rich_table,
-)
 
 logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
-def display_eps_estimates(symbol: str):
+def display_eps_estimates(
+    symbol: str, export: str = "", sheet_name: Optional[str] = None
+):
     """Display eps Estimates
 
     Parameters
@@ -32,13 +33,23 @@ def display_eps_estimates(symbol: str):
             show_index=False,
             title=f"{symbol.upper()} EPS History and Estimations",
         )
+
+        export_data(
+            export,
+            os.path.dirname(os.path.abspath(__file__)),
+            "eps_estimates",
+            eps_estimates,
+            sheet_name,
+        )
     else:
         console.print("No data found.")
         return
 
 
 @log_start_end(log=logger)
-def display_rev_estimates(symbol: str):
+def display_rev_estimates(
+    symbol: str, export: str = "", sheet_name: Optional[str] = None
+):
     """Display rev Estimates
 
     Parameters
@@ -56,6 +67,14 @@ def display_rev_estimates(symbol: str):
             show_index=False,
             title=f"{symbol.upper()} Revenue History and Estimations",
         )
+
+        export_data(
+            export,
+            os.path.dirname(os.path.abspath(__file__)),
+            "rev_estimates",
+            rev_estimates,
+            sheet_name,
+        )
     else:
         console.print("No data found.")
         return
