@@ -5,19 +5,19 @@ import logging
 import os
 from typing import List, Optional
 
+import matplotlib
 import numpy as np
 import pandas as pd
 from matplotlib import pyplot as plt
-import matplotlib
 
-from openbb_terminal.config_terminal import theme
 from openbb_terminal.config_plot import PLOT_DPI
+from openbb_terminal.config_terminal import theme
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
+    is_valid_axes_count,
     plot_autoscale,
     print_rich_table,
-    is_valid_axes_count,
 )
 from openbb_terminal.rich_config import console
 from openbb_terminal.stocks.government import quiverquant_model
@@ -34,7 +34,7 @@ def display_last_government(
     limit: int = 5,
     representative: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Display last government trading [Source: quiverquant.com]
 
@@ -89,7 +89,7 @@ def display_government_buys(
     limit: int = 10,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Top buy government trading [Source: quiverquant.com]
@@ -170,7 +170,7 @@ def display_government_sells(
     limit: int = 10,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Top sell government trading [Source: quiverquant.com]
@@ -252,7 +252,7 @@ def display_last_contracts(
     limit: int = 20,
     sum_contracts: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Last government contracts [Source: quiverquant.com]
@@ -367,7 +367,7 @@ def display_government_trading(
     past_transactions_months: int = 6,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Government trading for specific ticker [Source: quiverquant.com]
@@ -424,7 +424,7 @@ def display_contracts(
     past_transaction_days: int = 10,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Show government contracts for ticker [Source: quiverquant.com]
@@ -496,7 +496,7 @@ def display_qtr_contracts(
     limit: int = 5,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Quarterly contracts [Source: quiverquant.com]
@@ -603,7 +603,7 @@ def display_hist_contracts(
     symbol: str,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Show historical quarterly government contracts [Source: quiverquant.com]
@@ -686,7 +686,7 @@ def display_top_lobbying(
     limit: int = 10,
     raw: bool = False,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Top lobbying tickers based on total spent
