@@ -3,6 +3,7 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
@@ -13,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 @log_start_end(log=logger)
 def last_insider_activity(
-    symbol: str, limit: int = 10, export: str = "", sheet_name: str = None
+    symbol: str, limit: int = 10, export: str = "", sheet_name: Optional[str] = None
 ):
     """Display insider activity for a given stock ticker. [Source: Finviz]
 
