@@ -1,24 +1,25 @@
 """Option helper functions"""
 __docformat__ = "numpy"
 
-from datetime import datetime, timedelta
 import logging
+from datetime import datetime, timedelta
 from math import e, log
-from typing import Union, Tuple
+from typing import Optional, Tuple, Union
 
 import numpy as np
 import pandas as pd
 from scipy.stats import norm
 
-from openbb_terminal.rich_config import console
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import get_rf
+from openbb_terminal.rich_config import console
 
 logger = logging.getLogger(__name__)
 
 # pylint: disable=too-many-arguments
 
 
+@log_start_end(log=logger)
 def get_strikes(
     min_sp: float, max_sp: float, current_price: float
 ) -> Tuple[float, float]:
@@ -180,6 +181,9 @@ def process_option_chain(data: pd.DataFrame, source: str) -> pd.DataFrame:
 
         df = pd.concat([calls, puts]).drop_duplicates()
 
+    elif source == "Intrinio":
+        df = data.copy()
+
     elif source == "YahooFinance":
         call_columns = ["expiration", "strike"] + [
             col for col in data.columns if col.endswith("_c")
@@ -212,7 +216,7 @@ def get_greeks(
     puts: pd.DataFrame,
     expire: str,
     div_cont: float = 0,
-    rf: float = None,
+    rf: Optional[float] = None,
     opt_type: int = 0,
     show_all: bool = False,
     show_extra_greeks: bool = False,
@@ -257,10 +261,11 @@ def get_greeks(
     if not all(
         col in chain_columns for col in ["strike", "impliedVolatility", "optionType"]
     ):
-        console.print(
-            "[red]It's not possible to calculate the greeks without the following "
-            "columns: `strike`, `impliedVolatility`, `optionType`.\n[/red]"
-        )
+        if "delta" not in chain_columns:
+            console.print(
+                "[red]It's not possible to calculate the greeks without the following "
+                "columns: `strike`, `impliedVolatility`, `optionType`.\n[/red]"
+            )
         return pd.DataFrame()
 
     risk_free = rf if rf is not None else get_rf()
@@ -585,3 +590,171 @@ class Option:
             * norm.pdf(self.d1)
             / self._sigma
         )
+
+
+def delta_at_strike(
+    strike: Union[float, pd.Series, np.ndarray],
+    underlying_price: float,
+    iv: Union[float, pd.Series, np.ndarray],
+    dte: Union[float, pd.Series, np.ndarray],
+    option: Union[str, pd.Series, np.ndarray] = "call",
+    rf_rate: float = 0.03,
+) -> Union[float, pd.Series, np.ndarray]:
+    """Gets delta at a theoretical underlying
+
+    Parameters
+    ----------
+    strike : float
+        Option strike price
+    underlying_price : float
+        Underlying price for Black-Scholes calculation
+    iv : float
+        Implied volatility for calculation
+    dte : float
+        Time to expiration in years
+    option : str, optional
+        Type of option, either "call" or "put", by default "call"
+    rf_rate : float, optional
+        Risk free rate for calculation, by default 0.03
+
+    Returns
+    -------
+    float
+        Value of delta at theoretical underlying
+    """
+
+    d1 = (np.log(underlying_price / strike) + (rf_rate + 0.5 * iv**2) * dte) / (
+        iv * np.sqrt(dte)
+    )
+    return np.where(option == "call", norm.cdf(d1), norm.cdf(d1) - 1)
+
+
+def gamma_at_strike(
+    strike: Union[float, pd.Series, np.ndarray],
+    underlying_price: float,
+    iv: Union[float, pd.Series, np.ndarray],
+    dte: Union[float, pd.Series, np.ndarray],
+    rf_rate: float = 0.03,
+) -> Union[float, pd.Series, np.ndarray]:
+    """Get gamma at a theoretical underlying
+
+    Parameters
+    ----------
+    strike : Union[float,pd.Series]
+        Option strike price
+    underlying_price : float
+        Underlying price for Black-Scholes calculation
+    iv : float
+        Implied volatility for calculation
+    dte : float
+        Time to expiration in years
+    rf_rate : float, optional
+        Risk free rate for calculation, by default 0.03
+
+    Returns
+    -------
+    float
+        Value of delta at theoretical underlying
+    """
+    d1 = (np.log(underlying_price / strike) + (rf_rate + 0.5 * iv**2) * dte) / (
+        iv * np.sqrt(dte)
+    )
+    return norm.pdf(d1) / (underlying_price * iv * np.sqrt(dte))
+
+
+@log_start_end(log=logger)
+def get_abs_market_delta(
+    underlying_price: float, df: pd.DataFrame, rf_rate: float = 0.03
+) -> float:
+    """
+    Get the total market delta across entire chain.
+    In this calculation, we find delta at a theoretical underlying and then take the sum of delta x open interest.
+    Delta neutral is the theoretical underlying where this sum is 0.  To prepare the minimization, we take the absolute
+    value of this sum.
+
+    Parameters
+    ----------
+    underlying_price : float
+        Theoretical underlying price
+    df : pd.DataFrame
+        Dataframe of option chain.  Requires the following columns: impliedVolatility,dte,openInterest,strike,optionType
+    rf_rate : float, optional
+        Optional risk free rate for calculation, by default 0.03
+
+    Returns
+    -------
+    float
+        Market delta at underlying price.
+
+    Raises
+    ------
+    ValueError
+        If any of the required columns are not in the dataframe
+    """
+    for col in ["impliedVolatility", "dte", "openInterest", "strike", "optionType"]:
+        if col not in df.columns:
+            raise ValueError(f"{col} needs to be in df")
+    df["new_delta"] = delta_at_strike(
+        df.strike.to_numpy(),
+        underlying_price,
+        df.impliedVolatility.to_numpy(),
+        df.dte.to_numpy(),
+        df.optionType.to_numpy(),
+        rf_rate,
+    )
+    return np.abs(np.sum(df["new_delta"].to_numpy() * df["openInterest"].to_numpy()))
+
+
+@log_start_end(log=logger)
+def get_market_gamma(
+    underlying_price: float,
+    df: pd.DataFrame,
+    abs_mg: bool = True,
+    rf_rate: float = 0.03,
+):
+    """
+    Get the total market gamma across entire chain.
+    In this calculation, we find gamma at a theoretical underlying and then take the sum of delta x open interest.
+    Because gamma is positive, we define gamma for puts to be negative when taking the sum.
+    Gamma neutral is the theoretical underlying where this sum is 0.  To prepare the minimization, we take the absolute
+    value of this sum.
+    Gamma max is where the sum of the abolutele value of gamma x open interest is maximized.
+
+    Parameters
+    ----------
+    underlying_price : float
+        Theoretical underlying price
+    df : pd.DataFrame
+        Dataframe of option chain.  Requires the following columns: impliedVolatility,dte,openInterest,strike,optionType
+    abs_mg : bool, optional
+        Flag to indicate if getting gamma neutral by default True
+    rf_rate : float, optional
+        Optional float value for risk free rate, by default 0.03
+
+    Returns
+    -------
+    float
+        Value of gamma max or gamma neutral at the underlying price
+
+    Raises
+    ------
+    ValueError
+        If any of the required columns are not in the dataframe
+    """
+    for col in ["impliedVolatility", "dte", "openInterest", "strike", "optionType"]:
+        if col not in df.columns:
+            raise ValueError(f"{col} needs to be in df")
+    df["new_gamma"] = gamma_at_strike(
+        df.strike.to_numpy(),
+        underlying_price,
+        df.impliedVolatility.to_numpy(),
+        df.dte.to_numpy(),
+        rf_rate,
+    )
+    fact = np.where(df.optionType == "put", -1, 1)
+    mg = np.sum(df["new_gamma"].to_numpy() * df["openInterest"].to_numpy() * fact)
+    if abs_mg:
+        # gamma neutral
+        return np.abs(np.sum(mg))
+    # Gamma max
+    return -1 * np.sum(np.abs(mg))
