@@ -4,7 +4,7 @@ __docformat__ = "numpy"
 import argparse
 import logging
 from datetime import datetime, timedelta
-from typing import List
+from typing import List, Optional
 
 import pandas as pd
 
@@ -18,7 +18,6 @@ from openbb_terminal.helper_funcs import (
     EXPORT_ONLY_RAW_DATA_ALLOWED,
     parse_and_split_input,
     valid_date,
-    list_from_str,
 )
 from openbb_terminal.menu import session
 from openbb_terminal.parent_classes import BaseController
@@ -29,27 +28,28 @@ from openbb_terminal.stocks.options import (
     calculator_view,
     chartexchange_view,
     fdscanner_view,
+    intrinio_model,
+    intrinio_view,
     nasdaq_model,
-    op_helpers,
     tradier_model,
     tradier_view,
     yfinance_model,
     yfinance_view,
 )
 from openbb_terminal.stocks.options.hedge import hedge_controller
+from openbb_terminal.stocks.options.options_view import (
+    display_chains,
+    display_expiry_dates,
+    plot_oi,
+    plot_voi,
+    plot_vol,
+)
 from openbb_terminal.stocks.options.pricing import pricing_controller
 from openbb_terminal.stocks.options.screen import (
     screener_controller,
     syncretism_model,
     syncretism_view,
 )
-from openbb_terminal.stocks.options.options_view import (
-    plot_vol,
-    plot_oi,
-    plot_voi,
-    display_expiry_dates,
-    display_chains,
-)
 
 # pylint: disable=R1710,C0302,R0916,R0902
 
@@ -85,6 +85,7 @@ class OptionsController(BaseController):
         "binom",
         "vsurf",
         "greeks",
+        "eodchain",
     ]
     CHOICES_MENUS = [
         "pricing",
@@ -121,7 +122,11 @@ class OptionsController(BaseController):
     PATH = "/stocks/options/"
     CHOICES_GENERATION = True
 
-    def __init__(self, ticker: str, queue: List[str] = None):
+    def __init__(
+        self,
+        ticker: str,
+        queue: Optional[List[str]] = None,
+    ):
         """Constructor"""
         super().__init__(queue)
 
@@ -130,6 +135,7 @@ class OptionsController(BaseController):
         self.selected_date = ""
         self.chain: pd.DataFrame = pd.DataFrame()
         self.full_chain: pd.DataFrame = pd.DataFrame()
+
         self.current_price = 0.0
         # Keeps track of initial source of load so we can use correct commands later
         self.source = ""
@@ -182,6 +188,9 @@ class OptionsController(BaseController):
         elif self.source == "Nasdaq":
             df = nasdaq_model.get_full_option_chain(self.ticker)
 
+        elif self.source == "Intrinio":
+            df = intrinio_model.get_full_option_chain(self.ticker)
+
         else:
             self.source = "YahooFinance"
             df = yfinance_model.get_full_option_chain(self.ticker)
@@ -191,8 +200,7 @@ class OptionsController(BaseController):
         ):
             console.print("[red]Error loading option chain.[/red]")
             return
-
-        self.full_chain = op_helpers.process_option_chain(data=df, source=self.source)
+        self.full_chain = df.copy(deep=True)
         self.chain = self.full_chain.copy(deep=True)
 
         console.print("Loaded option chain from", self.source)
@@ -204,16 +212,13 @@ class OptionsController(BaseController):
                 self.current_price = last_price if last_price else 0.0
             elif self.source == "Nasdaq":
                 self.current_price = nasdaq_model.get_last_price(self.ticker)
+            elif self.source == "Intrinio":
+                self.current_price = intrinio_model.get_last_price(self.ticker)
             else:
                 self.current_price = yfinance_model.get_last_price(self.ticker)
 
     def set_expiry_dates(self):
-        if self.source == "Tradier":
-            self.expiry_dates = tradier_model.option_expirations(self.ticker)
-        elif self.source == "Nasdaq":
-            self.expiry_dates = nasdaq_model.option_expirations(self.ticker)
-        else:
-            self.expiry_dates = yfinance_model.option_expirations(self.ticker)
+        self.expiry_dates = self.full_chain.expiration.unique().tolist() or []
 
     def update_runtime_choices(self):
         """Update runtime choices"""
@@ -280,6 +285,7 @@ class OptionsController(BaseController):
         mt.add_cmd("parity", self.ticker and self.selected_date)
         mt.add_cmd("binom", self.ticker and self.selected_date)
         mt.add_cmd("greeks", self.ticker and self.selected_date)
+        mt.add_cmd("eodchain", self.ticker and self.selected_date)
         mt.add_raw("\n")
         mt.add_menu("pricing", self.ticker and self.selected_date)
         mt.add_menu("hedge", self.ticker and self.selected_date)
@@ -528,7 +534,7 @@ class OptionsController(BaseController):
             "--strike",
             dest="strike",
             type=float,
-            required="--chain" in other_args or "-h" not in other_args,
+            required="--chain" not in other_args and "-h" not in other_args,
             help="Strike price to look at",
         )
         parser.add_argument(
@@ -578,34 +584,54 @@ class OptionsController(BaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
-            if self.ticker:
-                if self.selected_date:
-                    if not self.chain.empty and (
-                        (
-                            ns_parser.put
-                            and ns_parser.strike
-                            in [float(strike) for strike in self.chain["strike"]]
-                        )
-                        or (
-                            not ns_parser.put
-                            and ns_parser.strike
-                            in [float(strike) for strike in self.chain["strike"]]
+            if self.ticker or "--chain" in other_args:
+                if self.selected_date or "--chain" in other_args:
+                    if (
+                        not self.chain.empty
+                        and (
+                            (
+                                ns_parser.put
+                                and ns_parser.strike
+                                in [float(strike) for strike in self.chain["strike"]]
+                            )
+                            or (
+                                not ns_parser.put
+                                and ns_parser.strike
+                                in [float(strike) for strike in self.chain["strike"]]
+                            )
                         )
+                        or "--chain" in other_args
                     ):
-                        syncretism_view.view_historical_greeks(
-                            symbol=self.ticker,
-                            expiry=self.selected_date,
-                            strike=ns_parser.strike,
-                            greek=ns_parser.greek,
-                            chain_id=ns_parser.chain_id,
-                            put=ns_parser.put,
-                            raw=ns_parser.raw,
-                            limit=ns_parser.limit,
-                            export=ns_parser.export,
-                            sheet_name=" ".join(ns_parser.sheet_name)
-                            if ns_parser.sheet_name
-                            else None,
-                        )
+                        if ns_parser.source == "Syncretism":
+                            syncretism_view.view_historical_greeks(
+                                symbol=self.ticker,
+                                expiry=self.selected_date,
+                                strike=ns_parser.strike,
+                                greek=ns_parser.greek,
+                                chain_id=ns_parser.chain_id,
+                                put=ns_parser.put,
+                                raw=ns_parser.raw,
+                                limit=ns_parser.limit,
+                                export=ns_parser.export,
+                                sheet_name=" ".join(ns_parser.sheet_name)
+                                if ns_parser.sheet_name
+                                else None,
+                            )
+                        if ns_parser.source == "Intrinio":
+                            intrinio_view.view_historical_greeks(
+                                symbol=self.ticker,
+                                expiry=self.selected_date,
+                                strike=ns_parser.strike,
+                                greek=ns_parser.greek,
+                                chain_id=ns_parser.chain_id,
+                                put=ns_parser.put,
+                                raw=ns_parser.raw,
+                                limit=ns_parser.limit,
+                                export=ns_parser.export,
+                                sheet_name=" ".join(ns_parser.sheet_name)
+                                if ns_parser.sheet_name
+                                else None,
+                            )
                     else:
                         console.print("No correct strike input")
                 else:
@@ -651,7 +677,7 @@ class OptionsController(BaseController):
                 )
                 console.print("Please try loading from a different source.")
                 console.print("Loading from YahooFinance now.")
-                self.expiry_dates = yfinance_model.option_expirations(self.ticker)
+                self.expiry_dates = nasdaq_model.option_expirations(self.ticker)
 
             self.update_runtime_choices()
 
@@ -748,7 +774,12 @@ class OptionsController(BaseController):
             help="Flag for showing put option",
         )
         parser.add_argument(
-            "-c", "--chain", dest="chain_id", type=str, help="OCC option symbol"
+            "-c",
+            "--chain",
+            dest="chain_id",
+            type=str,
+            help="Option symbol",
+            default=None,
         )
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-s")
@@ -760,40 +791,58 @@ class OptionsController(BaseController):
             limit=10,
         )
         if ns_parser:
-            if not self.ticker:
+            if not self.ticker and ns_parser.chain_id is None:
                 console.print("No ticker loaded. First use `load <ticker>`")
                 return
-            if not self.selected_date:
+            if not self.selected_date and ns_parser.chain_id is None:
                 console.print("No expiry loaded. First use `exp <expiry date>`")
                 return
-            if not self.chain.empty and (
-                (
-                    ns_parser.put
-                    and ns_parser.strike
-                    not in [float(strike) for strike in self.chain["strike"]]
-                )
-                or (
-                    not ns_parser.put
-                    and ns_parser.strike
-                    not in [float(strike) for strike in self.chain["strike"]]
+            if (
+                not self.chain.empty
+                and (
+                    (
+                        ns_parser.put
+                        and ns_parser.strike
+                        not in [float(strike) for strike in self.chain["strike"]]
+                    )
+                    or (
+                        not ns_parser.put
+                        and ns_parser.strike
+                        not in [float(strike) for strike in self.chain["strike"]]
+                    )
                 )
+                and ns_parser.chain_id is None
             ):
                 console.print("No correct strike input")
                 return
             if ns_parser.source == "ChartExchange":
                 chartexchange_view.display_raw(
-                    self.ticker,
-                    self.selected_date,
-                    not ns_parser.put,
-                    ns_parser.strike,
-                    ns_parser.limit,
-                    ns_parser.export,
+                    symbol=self.ticker,
+                    expiry=self.selected_date,
+                    call=not ns_parser.put,
+                    price=ns_parser.strike,
+                    limit=ns_parser.limit,
+                    export=ns_parser.export,
+                    chain_id=ns_parser.chain_id,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
+            if ns_parser.source == "Intrinio":
+                intrinio_view.display_historical(
+                    symbol=self.ticker,
+                    expiry=self.selected_date,
+                    strike=ns_parser.strike,
+                    put=ns_parser.put,
+                    raw=ns_parser.raw,
+                    chain_id=ns_parser.chain_id,
+                    export=ns_parser.export,
                     sheet_name=" ".join(ns_parser.sheet_name)
                     if ns_parser.sheet_name
                     else None,
                 )
 
-            elif (
+            if (
                 ns_parser.source == "Tradier" and API_TRADIER_TOKEN != "REPLACE_ME"
             ):  # nosec
                 tradier_view.display_historical(
@@ -808,8 +857,6 @@ class OptionsController(BaseController):
                     if ns_parser.sheet_name
                     else None,
                 )
-            else:
-                console.print("TRADIER TOKEN not supplied.")
 
     @log_start_end(log=logger)
     def call_chains(self, other_args: List[str]):
@@ -900,7 +947,6 @@ class OptionsController(BaseController):
                         sheet_name=" ".join(ns_parser.sheet_name)
                         if ns_parser.sheet_name
                         else None,
-                        to_display=list_from_str(ns_parser.to_display),
                     )
                 else:
                     console.print(
@@ -1542,3 +1588,31 @@ class OptionsController(BaseController):
     def call_screen(self, _):
         """Process screen command"""
         self.queue = screener_controller.ScreenerController(self.queue).menu()
+
+    @log_start_end(log=logger)
+    def call_eodchain(self, other_args: List[str]):
+        """Process greeks command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="eodchain",
+            description="Get full option chain at a given end of day.",
+        )
+        parser.add_argument(
+            "-d",
+            "--date",
+            type=valid_date,
+            dest="date",
+            help="Date to get option chain for.  Format YYYY-MM-DD",
+            required="-h" not in other_args,
+        )
+
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+
+        if ns_parser:
+            if not self.ticker:
+                console.print("No ticker loaded. First use `load <ticker>`")
+                return
+            self.full_chain = intrinio_model.get_full_chain_eod(
+                self.ticker, datetime.strftime(ns_parser.date, "%Y-%m-%d")
+            )
