@@ -1,17 +1,21 @@
 """Options Functions For OpenBB SDK"""
 
 import logging
-from typing import Union
+from typing import Optional, Union
 
+import numpy as np
 import pandas as pd
+from scipy.optimize import minimize
 
 from openbb_terminal.decorators import log_start_end
+from openbb_terminal.rich_config import console
 from openbb_terminal.stocks.options import (
     chartexchange_model,
+    intrinio_model,
     nasdaq_model,
+    op_helpers,
     tradier_model,
     yfinance_model,
-    op_helpers,
 )
 
 logger = logging.getLogger(__name__)
@@ -28,7 +32,7 @@ def get_full_option_chain(
     symbol : str
         Symbol to get chain for
     source : str, optional
-        Source to get data from, by default "Nasdaq"
+        Source to get data from, by default "Nasdaq".  Can be YahooFinance, Tradier, Nasdaq, or Intrinio
     expiration : Union[str, None], optional
         Date to get chain for.  By default returns all dates
 
@@ -56,6 +60,9 @@ def get_full_option_chain(
     elif source == "YahooFinance":
         df = yfinance_model.get_full_option_chain(symbol)
 
+    elif source == "Intrinio":
+        df = intrinio_model.get_full_option_chain(symbol)
+
     else:
         logger.info("Invalid Source")
         return pd.DataFrame()
@@ -63,7 +70,7 @@ def get_full_option_chain(
     if expiration:
         df = df[df.expiration == expiration]
 
-    return op_helpers.process_option_chain(df, source)
+    return df
 
 
 def get_option_current_price(
@@ -129,11 +136,13 @@ def get_option_expirations(symbol: str, source: str = "Nasdaq") -> list:
         return yfinance_model.option_expirations(symbol)
     if source == "Nasdaq":
         return nasdaq_model.option_expirations(symbol)
-
+    if source == "Intrinio":
+        return intrinio_model.get_expiration_dates(symbol)
     logger.info("Invalid Source")
     return pd.DataFrame()
 
 
+@log_start_end(log=logger)
 def hist(
     symbol: str,
     exp: str,
@@ -168,10 +177,61 @@ def hist(
 
     Because this generates a dataframe, we can easily plot the close price for a SPY put:
     (Note that Tradier requires an API key)
-    >>> openbb.stocks.options.hist("SPY", "2022-11-18", 400, call=False, source="Tradier").plot(y="close)
+    >>> openbb.stocks.options.hist("SPY", "2022-11-18", 400, call=False, source="Tradier").plot(y="close")
     """
     if source.lower() == "chartexchange":
         return chartexchange_model.get_option_history(symbol, exp, call, strike)
     if source.lower() == "tradier":
         return tradier_model.get_historical_options(symbol, exp, strike, not call)
+    if source.lower() == "intrinio":
+        occ_symbol = f"{symbol}{''.join(exp[2:].split('-'))}{'C' if call else 'P'}{str(int(1000*strike)).zfill(8)}"
+        return intrinio_model.get_historical_options(occ_symbol)
     return pd.DataFrame()
+
+
+def get_delta_neutral(symbol: str, date: str, x0: Optional[float] = None) -> float:
+    """Get delta neutral price for symbol at a given close date
+
+    Parameters
+    ----------
+    symbol : str
+        Symbol to get delta neutral price for
+    date : str
+        Date to get delta neutral price for
+    x0 : float, optional
+        Optional initial guess for solver, defaults to close price of that day
+
+    Returns
+    -------
+    float
+        Delta neutral price
+    """
+    # Need an initial guess for the solver
+    if x0:
+        x0_guess = x0
+    else:
+        # Check that the close price exists.  I am finding that holidays are not consistent, such as June 20, 2022
+        try:
+            x0_guess = intrinio_model.get_close_at_date(symbol, date)
+        except Exception:
+            console.print("Error getting close price for symbol, check date and symbol")
+            return np.nan
+    x0_guess = x0 if x0 else intrinio_model.get_close_at_date(symbol, date)
+    chains = intrinio_model.get_full_chain_eod(symbol, date)
+    if chains.empty:
+        return np.nan
+    # Lots of things can go wrong with minimizing, so lets add a general exception catch here.
+    try:
+        res = minimize(
+            op_helpers.get_abs_market_delta,
+            x0=x0_guess,
+            args=(chains),
+            bounds=[(0.01, np.inf)],
+            method="l-bfgs-b",
+        )
+        return res.x[0]
+    except Exception as e:
+        logging.info(
+            "Error getting delta neutral price for %s on %s: error:%s", symbol, date, e
+        )
+        return np.nan
