@@ -74,7 +74,7 @@ def plot_plot(
     y: str = "iv",
     custom: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Generate a graph custom graph based on user input
@@ -223,10 +223,10 @@ def show_parity(
     expiry: str,
     put: bool = False,
     ask: bool = False,
-    mini: float = None,
-    maxi: float = None,
+    mini: Optional[float] = None,
+    maxi: Optional[float] = None,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Prints options and whether they are under or over priced [Source: Yahoo Finance]
 
@@ -337,9 +337,9 @@ def risk_neutral_vals(
     expiry: str,
     data: pd.DataFrame,
     put: bool = False,
-    mini: float = None,
-    maxi: float = None,
-    risk: float = None,
+    mini: Optional[float] = None,
+    maxi: Optional[float] = None,
+    risk: Optional[float] = None,
 ) -> None:
     """Prints current options prices and risk neutral values [Source: Yahoo Finance]
 
@@ -516,7 +516,7 @@ def show_binom(
     europe: bool = False,
     export: str = "",
     plot: bool = False,
-    vol: float = None,
+    vol: Optional[float] = None,
 ) -> None:
     """Get binomial pricing for option
 
@@ -559,7 +559,7 @@ def show_binom(
 def display_vol_surface(
     symbol: str,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
     z: str = "IV",
     external_axes: Optional[List[plt.Axes]] = None,
 ):
@@ -619,7 +619,7 @@ def show_greeks(
     symbol: str,
     expiry: str,
     div_cont: float = 0,
-    rf: float = None,
+    rf: Optional[float] = None,
     opt_type: int = 1,
     mini: float = -1,
     maxi: float = -1,
