@@ -3,13 +3,15 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
 
 import matplotlib.pyplot as plt
 import pandas as pd
+
 from openbb_terminal.decorators import log_start_end
+from openbb_terminal.helper_funcs import export_data
 from openbb_terminal.rich_config import console
 from openbb_terminal.stocks.quantitative_analysis.beta_model import beta_model
-from openbb_terminal.helper_funcs import export_data
 
 logger = logging.getLogger(__name__)
 
@@ -18,11 +20,11 @@ logger = logging.getLogger(__name__)
 def beta_view(
     symbol: str,
     ref_symbol: str,
-    data: pd.DataFrame = None,
-    ref_data: pd.DataFrame = None,
+    data: Optional[pd.DataFrame] = None,
+    ref_data: Optional[pd.DataFrame] = None,
     interval: int = 1440,
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ) -> None:
     """Display the beta scatterplot + linear regression.
 
