@@ -3,11 +3,11 @@ __docformat__ = "numpy"
 
 import logging
 
-import requests
 from finvizfinance.quote import finvizfinance
 from finvizfinance.util import headers
 
 from openbb_terminal.decorators import log_start_end
+from openbb_terminal.helper_funcs import request
 
 logger = logging.getLogger(__name__)
 
@@ -29,7 +29,7 @@ def get_finviz_image(symbol: str) -> bytes:
     stock = finvizfinance(symbol)
     image_url = stock.ticker_charts(urlonly=True)
 
-    r = requests.get(image_url, stream=True, headers=headers, timeout=5)
+    r = request(image_url, stream=True, headers=headers)
     r.raise_for_status()
     r.raw.decode_content = True
     return r.content
