@@ -4,14 +4,12 @@ __docformat__ = "numpy"
 
 import argparse
 import logging
-import webbrowser
 from datetime import datetime
-from typing import List
+from typing import List, Optional
 
 import pandas as pd
 
 from openbb_terminal import feature_flags as obbff
-from openbb_terminal.custom_prompt_toolkit import NestedCompleter
 from openbb_terminal.common.technical_analysis import (
     custom_indicators_view,
     momentum_view,
@@ -22,6 +20,7 @@ from openbb_terminal.common.technical_analysis import (
     volatility_view,
     volume_view,
 )
+from openbb_terminal.custom_prompt_toolkit import NestedCompleter
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     EXPORT_BOTH_RAW_DATA_AND_FIGURES,
@@ -33,24 +32,28 @@ from openbb_terminal.helper_funcs import (
 )
 from openbb_terminal.menu import session
 from openbb_terminal.parent_classes import StockBaseController
-from openbb_terminal.rich_config import console, MenuText
+from openbb_terminal.rich_config import MenuText, console
 from openbb_terminal.stocks.technical_analysis import (
     finbrain_view,
     finviz_view,
+    rsp_view,
     tradingview_model,
     tradingview_view,
-    rsp_view,
 )
 
 logger = logging.getLogger(__name__)
 
 
+def no_ticker_message():
+    """Print message when no ticker is loaded"""
+    console.print("[red]No data loaded. Use 'load' command to load a symbol[/red]")
+
+
 class TechnicalAnalysisController(StockBaseController):
     """Technical Analysis Controller class"""
 
     CHOICES_COMMANDS = [
         "load",
-        "view",
         "summary",
         "recom",
         "ema",
@@ -75,7 +78,6 @@ class TechnicalAnalysisController(StockBaseController):
         "adosc",
         "obv",
         "fib",
-        "tv",
         "clenow",
         "demark",
         "atr",
@@ -89,7 +91,7 @@ class TechnicalAnalysisController(StockBaseController):
         start: datetime,
         interval: str,
         stock: pd.DataFrame,
-        queue: List[str] = None,
+        queue: Optional[List[str]] = None,
     ):
         """Constructor"""
         super().__init__(queue)
@@ -162,20 +164,6 @@ class TechnicalAnalysisController(StockBaseController):
         return []
 
     # SPECIFIC
-
-    @log_start_end(log=logger)
-    def call_tv(self, other_args):
-        """Process tv command"""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="tv",
-            description="""View TradingView for technical analysis. [Source: TradingView]""",
-        )
-        ns_parser = self.parse_known_args_and_warn(parser, other_args)
-        if ns_parser:
-            webbrowser.open(f"https://www.tradingview.com/chart/?symbol={self.ticker}")
-
     @log_start_end(log=logger)
     def call_view(self, other_args: List[str]):
         """Process view command"""
@@ -189,6 +177,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_ONLY_FIGURES_ALLOWED
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             finviz_view.view(self.ticker)
 
     @log_start_end(log=logger)
@@ -209,6 +200,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_ONLY_RAW_DATA_ALLOWED
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             finbrain_view.technical_summary_report(self.ticker)
 
     @log_start_end(log=logger)
@@ -259,6 +253,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_ONLY_RAW_DATA_ALLOWED
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             tradingview_view.print_recommendation(
                 symbol=self.ticker,
                 screener=ns_parser.screener,
@@ -317,6 +314,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             overlap_view.view_ma(
                 ma_type="EMA",
                 symbol=self.ticker,
@@ -372,6 +372,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             overlap_view.view_ma(
                 ma_type="SMA",
                 symbol=self.ticker,
@@ -424,6 +427,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             overlap_view.view_ma(
                 ma_type="WMA",
                 symbol=self.ticker,
@@ -476,6 +482,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             overlap_view.view_ma(
                 ma_type="HMA",
                 symbol=self.ticker,
@@ -531,6 +540,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             overlap_view.view_ma(
                 ma_type="ZLMA",
                 symbol=self.ticker,
@@ -583,6 +595,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             # Daily
             if self.interval == "1440min":
                 if ns_parser.start:
@@ -648,6 +663,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             momentum_view.display_cci(
                 symbol=self.ticker,
                 data=self.stock,
@@ -707,6 +725,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             momentum_view.display_macd(
                 symbol=self.ticker,
                 data=self.stock["Adj Close"],
@@ -770,6 +791,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             momentum_view.display_rsi(
                 symbol=self.ticker,
                 data=self.stock["Adj Close"],
@@ -815,6 +839,9 @@ class TechnicalAnalysisController(StockBaseController):
         )
 
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             rsp_view.display_rsp(
                 s_ticker=self.ticker,
                 export=ns_parser.export,
@@ -871,6 +898,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             momentum_view.display_stoch(
                 symbol=self.ticker,
                 data=self.stock,
@@ -915,6 +945,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             momentum_view.display_fisher(
                 symbol=self.ticker,
                 data=self.stock,
@@ -957,6 +990,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             momentum_view.display_cg(
                 symbol=self.ticker,
                 data=self.stock["Adj Close"],
@@ -1015,6 +1051,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             trend_indicators_view.display_adx(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1074,6 +1113,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             trend_indicators_view.display_aroon(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1142,6 +1184,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             volatility_view.display_bbands(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1193,6 +1238,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             volatility_view.display_donchian(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1264,6 +1312,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             volatility_view.view_kc(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1309,6 +1360,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             volume_view.display_ad(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1364,6 +1418,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             volume_view.display_adosc(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1398,6 +1455,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             volume_view.display_obv(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1446,6 +1506,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             custom_indicators_view.fibonacci_retracement(
                 symbol=self.ticker,
                 data=self.stock,
@@ -1480,6 +1543,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_ONLY_FIGURES_ALLOWED
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             if self.interval == "1440min":
                 momentum_view.display_clenow_momentum(
                     self.stock["Adj Close"],
@@ -1514,6 +1580,9 @@ class TechnicalAnalysisController(StockBaseController):
             parser, other_args, EXPORT_BOTH_RAW_DATA_AND_FIGURES
         )
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             momentum_view.display_demark(
                 self.stock,
                 self.ticker.upper(),
@@ -1569,6 +1638,9 @@ class TechnicalAnalysisController(StockBaseController):
         )
 
         if ns_parser:
+            if not self.ticker:
+                no_ticker_message()
+                return
             volatility_view.display_atr(
                 data=self.stock,
                 symbol=self.ticker,
