@@ -3,12 +3,14 @@ __docformat__ = "numpy"
 
 import logging
 import os
+from typing import Optional
+
 import pandas as pd
 
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import export_data, print_rich_table
-from openbb_terminal.stocks.technical_analysis import tradingview_model
 from openbb_terminal.rich_config import console
+from openbb_terminal.stocks.technical_analysis import tradingview_model
 
 logger = logging.getLogger(__name__)
 
@@ -20,7 +22,7 @@ def print_recommendation(
     exchange: str = "",
     interval: str = "",
     export: str = "",
-    sheet_name: str = None,
+    sheet_name: Optional[str] = None,
 ):
     """Print tradingview recommendation based on technical indicators
 
